/* automatically generated from accessibility-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (accessibility_dialog_ui)
#endif
#ifdef __GNUC__
static const char accessibility_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char accessibility_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.13\"/"
  "><object class=\"GtkAdjustment\" id=\"bounce-keys-delay\"><property nam"
  "e=\"lower\">50</property><property name=\"upper\">1000</property><prope"
  "rty name=\"value\">500</property><property name=\"step_increment\">1</p"
  "roperty><property name=\"page_increment\">10</property></object><object"
  " class=\"GtkImage\" id=\"image3\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"icon"
  "_name\">help-browser</property></object><object class=\"GtkImage\" id=\""
  "image4\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"icon_name\">window-close-symb"
  "olic</property></object><object class=\"GtkAdjustment\" id=\"mouse-emul"
  "ation-curve\"><property name=\"lower\">-1000</property><property name=\""
  "upper\">1000</property><property name=\"step_increment\">10</property><"
  "property name=\"page_increment\">100</property></object><object class=\""
  "GtkAdjustment\" id=\"mouse-emulation-delay\"><property name=\"lower\">1"
  "</property><property name=\"upper\">1000</property><property name=\"val"
  "ue\">150</property><property name=\"step_increment\">10</property><prop"
  "erty name=\"page_increment\">100</property></object><object class=\"Gtk"
  "Adjustment\" id=\"mouse-emulation-interval\"><property name=\"lower\">1"
  "0</property><property name=\"upper\">1000</property><property name=\"va"
  "lue\">20</property><property name=\"step_increment\">1</property><prope"
  "rty name=\"page_increment\">10</property></object><object class=\"GtkAd"
  "justment\" id=\"mouse-emulation-max-speed\"><property name=\"lower\">1<"
  "/property><property name=\"upper\">2000</property><property name=\"valu"
  "e\">1000</property><property name=\"step_increment\">10</property><prop"
  "erty name=\"page_increment\">100</property></object><object class=\"Gtk"
  "Adjustment\" id=\"mouse-emulation-time-to-max\"><property name=\"lower\""
  ">100</property><property name=\"upper\">10000</property><property name="
  "\"value\">3000</property><property name=\"step_increment\">10</property"
  "><property name=\"page_increment\">100</property></object><object class"
  "=\"GtkAdjustment\" id=\"slow-keys-delay\"><property name=\"lower\">50</"
  "property><property name=\"upper\">1000</property><property name=\"value"
  "\">500</property><property name=\"step_increment\">10</property><proper"
  "ty name=\"page_increment\">100</property></object><object class=\"XfceT"
  "itledDialog\" id=\"dialog\"><property name=\"can_focus\">False</propert"
  "y><property name=\"title\" translatable=\"yes\">Accessibility</property"
  "><property name=\"window_position\">center-on-parent</property><propert"
  "y name=\"default_width\">400</property><property name=\"default_height\""
  ">600</property><property name=\"icon_name\">org.xfce.settings.accessibi"
  "lity</property><property name=\"type_hint\">dialog</property><child int"
  "ernal-child=\"vbox\"><object class=\"GtkBox\" id=\"dialog-vbox1\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"orientation\">vertical</property><property "
  "name=\"spacing\">2</property><child internal-child=\"action_area\"><obj"
  "ect class=\"GtkButtonBox\" id=\"dialog-action_area1\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"layout_style\">end</property><child><object class=\"Gtk"
  "Button\" id=\"button2\"><property name=\"label\" translatable=\"yes\">_"
  "Close</property><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">True</property><property name=\"receives_default\">True"
  "</property><property name=\"image\">image4</property><property name=\"u"
  "se_underline\">True</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">False</property><property na"
  "me=\"position\">0</property></packing></child><child><object class=\"Gt"
  "kButton\" id=\"button1\"><property name=\"label\" translatable=\"yes\">"
  "_Help</property><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">True</property><property name=\"receives_default\">True"
  "</property><property name=\"image\">image3</property><property name=\"u"
  "se_underline\">True</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">False</property><property na"
  "me=\"position\">0</property><property name=\"secondary\">True</property"
  "></packing></child></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"fill\">True</property><property name=\"pack_ty"
  "pe\">end</property><property name=\"position\">0</property></packing></"
  "child><child><object class=\"GtkBox\" id=\"plug-child\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"orientation\">vertical</property><child><object class"
  "=\"GtkNotebook\" id=\"notebook1\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">True</property><property name=\"borde"
  "r_width\">6</property><child><object class=\"GtkBox\" id=\"vbox1\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"border_width\">12</property><property name"
  "=\"orientation\">vertical</property><property name=\"spacing\">18</prop"
  "erty><child><object class=\"GtkFrame\" id=\"start-at-frame\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"label_xalign\">0</property><property name=\"shad"
  "ow_type\">none</property><child><object class=\"GtkBox\" id=\"start-at-"
  "box\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"margin_top\">6</property><proper"
  "ty name=\"orientation\">vertical</property><property name=\"spacing\">6"
  "</property><child><object class=\"GtkLabel\" id=\"start-at-text\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"label\" translatable=\"yes\">When enabled, "
  "the session manager will start the required applications for screen rea"
  "ders and magnifiers.</property><property name=\"wrap\">True</property><"
  "property name=\"xalign\">0</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">0</property></packing></child><child><object class"
  "=\"GtkAlignment\" id=\"start-at-alignment\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"left_padding\">12</property><child><object class=\"GtkCheckButton"
  "\" id=\"start-at\"><property name=\"label\" translatable=\"yes\">_Enabl"
  "e assistive technologies</property><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">True</property><property name=\"rece"
  "ives_default\">False</property><property name=\"halign\">start</propert"
  "y><property name=\"use_underline\">True</property><property name=\"draw"
  "_indicator\">True</property></object></child></object><packing><propert"
  "y name=\"expand\">False</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">1</property></packing></child></object></"
  "child><child type=\"label\"><object class=\"GtkLabel\" id=\"start-at-la"
  "bel\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label\" translatable=\"yes\">Sta"
  "rt With Session</property><attributes><attribute name=\"weight\" value="
  "\"bold\"/></attributes></object></child></object><packing><property nam"
  "e=\"expand\">True</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">0</property></packing></child><child><object cl"
  "ass=\"GtkBox\" id=\"info-logout\"><property name=\"can_focus\">False</p"
  "roperty><property name=\"spacing\">12</property><child><object class=\""
  "GtkImage\" id=\"image1\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"stock\">gtk-i"
  "nfo</property><property name=\"icon_size\">5</property></object><packin"
  "g><property name=\"expand\">False</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">0</property></packing></child><"
  "child><object class=\"GtkLabel\" id=\"label18\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"halign\">start</property><property name=\"label\" translatabl"
  "e=\"yes\">Assistive technologies will be available the next time you lo"
  "gin</property><property name=\"wrap\">True</property><property name=\"x"
  "align\">0</property></object><packing><property name=\"expand\">True</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">1</property></packing></child></object><packing><property name=\"ex"
  "pand\">False</property><property name=\"fill\">True</property><property"
  " name=\"position\">1</property></packing></child><child><object class=\""
  "GtkBox\" id=\"info-no-at\"><property name=\"can_focus\">False</property"
  "><property name=\"spacing\">12</property><child><object class=\"GtkImag"
  "e\" id=\"image2\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"stock\">gtk-dialog-w"
  "arning</property><property name=\"icon_size\">5</property></object><pac"
  "king><property name=\"expand\">False</property><property name=\"fill\">"
  "True</property><property name=\"position\">0</property></packing></chil"
  "d><child><object class=\"GtkLabel\" id=\"label20\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"halign\">start</property><property name=\"label\" translat"
  "able=\"yes\">No AT-SPI provider was found on your system</property><pro"
  "perty name=\"wrap\">True</property><property name=\"xalign\">0</propert"
  "y></object><packing><property name=\"expand\">True</property><property "
  "name=\"fill\">True</property><property name=\"position\">1</property></"
  "packing></child></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">2</property></packing></child></object></child><child type=\"tab\"><ob"
  "ject class=\"GtkLabel\" id=\"label17\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "label\" translatable=\"yes\">Assistive _Technologies</property><propert"
  "y name=\"use_underline\">True</property></object><packing><property nam"
  "e=\"position\">2</property><property name=\"tab_fill\">False</property>"
  "</packing></child><child><object class=\"GtkScrolledWindow\" id=\"keybo"
  "ard-scrolled\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><child><object class=\"GtkViewport\" id=\""
  "keyboard-scrolled-viewport\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><child><object class=\"Gtk"
  "Box\" id=\"vbox2\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"border_width\">12</"
  "property><property name=\"orientation\">vertical</property><property na"
  "me=\"spacing\">18</property><child><object class=\"GtkFrame\" id=\"fram"
  "e1\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"label_xalign\">0</property><prope"
  "rty name=\"shadow_type\">none</property><child><object class=\"GtkBox\""
  " id=\"vbox3\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"margin_top\">6</property"
  "><property name=\"orientation\">vertical</property><property name=\"spa"
  "cing\">6</property><child><object class=\"GtkLabel\" id=\"sticky-keys-t"
  "ext\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label\" translatable=\"yes\">Whe"
  "n enabled, modifier keys (such as Control, Alt, and Shift) do not need "
  "to be held down (they can be pressed and then released) when multiple k"
  "eys would normally need to be pressed at the same time.</property><prop"
  "erty name=\"wrap\">True</property><property name=\"xalign\">0</property"
  "></object><packing><property name=\"expand\">False</property><property "
  "name=\"fill\">True</property><property name=\"position\">0</property></"
  "packing></child><child><object class=\"GtkAlignment\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"left_padding\">12</property><child><object class=\"GtkB"
  "ox\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"orientation\">vertical</property>"
  "<property name=\"spacing\">6</property><child><object class=\"GtkCheckB"
  "utton\" id=\"sticky-keys-enabled\"><property name=\"label\" translatabl"
  "e=\"yes\">_Use sticky keys</property><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">True</property><property name=\"re"
  "ceives_default\">False</property><property name=\"halign\">start</prope"
  "rty><property name=\"use_underline\">True</property><property name=\"dr"
  "aw_indicator\">True</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "Alignment\" id=\"sticky-keys-box\"><property name=\"visible\">True</pro"
  "perty><property name=\"sensitive\">False</property><property name=\"can"
  "_focus\">False</property><property name=\"left_padding\">12</property><"
  "child><object class=\"GtkBox\" id=\"vbox7\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"orientation\">vertical</property><property name=\"spacing\">6</pr"
  "operty><child><object class=\"GtkCheckButton\" id=\"sticky-keys-latch-t"
  "o-lock\"><property name=\"label\" translatable=\"yes\">_Lock sticky key"
  "s</property><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">False</p"
  "roperty><property name=\"tooltip_text\" translatable=\"yes\">When selec"
  "ted, modifier keys (such as Control, Alt, and Shift) will remain locked"
  " in the pressed state until pressed again</property><property name=\"ha"
  "lign\">start</property><property name=\"use_underline\">True</property>"
  "<property name=\"draw_indicator\">True</property></object><packing><pro"
  "perty name=\"expand\">True</property><property name=\"fill\">True</prop"
  "erty><property name=\"position\">0</property></packing></child><child><"
  "object class=\"GtkCheckButton\" id=\"sticky-keys-two-keys-disable\"><pr"
  "operty name=\"label\" translatable=\"yes\">Disable sticky keys if two k"
  "eys are _pressed</property><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">True</property><property name=\"receives_def"
  "ault\">False</property><property name=\"tooltip_text\" translatable=\"y"
  "es\">When selected, the \"sticky keys\" feature will be disabled if two"
  " keys are pressed simultaneously</property><property name=\"halign\">st"
  "art</property><property name=\"use_underline\">True</property><property"
  " name=\"draw_indicator\">True</property></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">False</property><p"
  "roperty name=\"position\">1</property></packing></child></object></chil"
  "d></object><packing><property name=\"expand\">True</property><property "
  "name=\"fill\">True</property><property name=\"position\">1</property></"
  "packing></child></object></child></object><packing><property name=\"exp"
  "and\">False</property><property name=\"fill\">False</property><property"
  " name=\"position\">1</property></packing></child></object></child><chil"
  "d type=\"label\"><object class=\"GtkLabel\" id=\"label3\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"label\" translatable=\"yes\">Sticky Keys</property>"
  "<attributes><attribute name=\"weight\" value=\"bold\"/></attributes></o"
  "bject></child></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">False</property><property name=\"position\">"
  "0</property></packing></child><child><object class=\"GtkFrame\" id=\"fr"
  "ame2\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"label_xalign\">0</property><pro"
  "perty name=\"shadow_type\">none</property><child><object class=\"GtkBox"
  "\" id=\"vbox4\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"margin_top\">6</proper"
  "ty><property name=\"orientation\">vertical</property><property name=\"s"
  "pacing\">6</property><child><object class=\"GtkLabel\" id=\"slow-keys-t"
  "ext\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label\" translatable=\"yes\">To "
  "help prevent accidental keystrokes, slow keys requires that a key is he"
  "ld for a certain minimum amount of time before the keystroke will be ac"
  "cepted.</property><property name=\"wrap\">True</property><property name"
  "=\"xalign\">0</property></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">0</property></packing></child><child><object class=\"GtkAlignm"
  "ent\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"left_padding\">12</property><chi"
  "ld><object class=\"GtkBox\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"orientatio"
  "n\">vertical</property><property name=\"spacing\">6</property><child><o"
  "bject class=\"GtkCheckButton\" id=\"slow-keys-enabled\"><property name="
  "\"label\" translatable=\"yes\">Use slow _keys</property><property name="
  "\"visible\">True</property><property name=\"can_focus\">True</property>"
  "<property name=\"receives_default\">False</property><property name=\"ha"
  "lign\">start</property><property name=\"use_underline\">True</property>"
  "<property name=\"draw_indicator\">True</property></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">True</pro"
  "perty><property name=\"position\">0</property></packing></child><child>"
  "<object class=\"GtkAlignment\" id=\"slow-keys-box\"><property name=\"vi"
  "sible\">True</property><property name=\"sensitive\">False</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"left_padding"
  "\">12</property><child><object class=\"GtkBox\" id=\"hbox1\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"spacing\">12</property><child><object class=\"Gt"
  "kLabel\" id=\"label6\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"label\" transla"
  "table=\"yes\">Acceptance _delay:</property><property name=\"use_underli"
  "ne\">True</property><property name=\"mnemonic_widget\">slow-keys-scale<"
  "/property></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">False</property><property name=\"position\">0</p"
  "roperty></packing></child><child><object class=\"GtkScale\" id=\"slow-k"
  "eys-scale\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"tooltip_text\" translatable"
  "=\"yes\">The amount of time, in milliseconds, that must elapse before a"
  " keystroke will be accepted</property><property name=\"adjustment\">slo"
  "w-keys-delay</property><property name=\"round_digits\">0</property><pro"
  "perty name=\"digits\">0</property><property name=\"value_pos\">right</p"
  "roperty></object><packing><property name=\"expand\">True</property><pro"
  "perty name=\"fill\">True</property><property name=\"position\">1</prope"
  "rty></packing></child></object></child></object><packing><property name"
  "=\"expand\">True</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">1</property></packing></child></object></child><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">False</property><property name=\"position\">1</property></p"
  "acking></child></object></child><child type=\"label\"><object class=\"G"
  "tkLabel\" id=\"label4\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"label\" transl"
  "atable=\"yes\">Slow Keys</property><attributes><attribute name=\"weight"
  "\" value=\"bold\"/></attributes></object></child></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">False</pr"
  "operty><property name=\"position\">1</property></packing></child><child"
  "><object class=\"GtkFrame\" id=\"frame3\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"label_xalign\">0</property><property name=\"shadow_type\">none</pro"
  "perty><child><object class=\"GtkBox\" id=\"vbox6\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"margin_top\">6</property><property name=\"orientation\">ve"
  "rtical</property><property name=\"spacing\">6</property><child><object "
  "class=\"GtkLabel\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"label\" translatabl"
  "e=\"yes\">To help prevent accidental multiple keystrokes, bounce keys i"
  "mposes a minimum delay between keystrokes.</property><property name=\"w"
  "rap\">True</property><property name=\"xalign\">0</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkAlignment\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"left_padding\">12</property><child><object class=\"GtkBox\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"orientation\">vertical</property><property nam"
  "e=\"spacing\">6</property><child><object class=\"GtkCheckButton\" id=\""
  "bounce-keys-enabled\"><property name=\"label\" translatable=\"yes\">Use"
  " _bounce keys</property><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">True</property><property name=\"receives_defaul"
  "t\">False</property><property name=\"halign\">start</property><property"
  " name=\"use_underline\">True</property><property name=\"draw_indicator\""
  ">True</property></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkAlignment\" id"
  "=\"bounce-keys-box\"><property name=\"visible\">True</property><propert"
  "y name=\"sensitive\">False</property><property name=\"can_focus\">False"
  "</property><property name=\"left_padding\">12</property><child><object "
  "class=\"GtkBox\" id=\"hbox2\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"spacing\""
  ">12</property><child><object class=\"GtkLabel\" id=\"label9\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"label\" translatable=\"yes\">K_eystroke delay:<"
  "/property><property name=\"use_underline\">True</property><property nam"
  "e=\"mnemonic_widget\">bounce-keys-scale</property></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">False</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkScale\" id=\"bounce-keys-scale\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"tooltip_text\" translatable=\"yes\">The amount of time, "
  "in milliseconds, required between keystrokes</property><property name=\""
  "adjustment\">bounce-keys-delay</property><property name=\"round_digits\""
  ">0</property><property name=\"digits\">0</property><property name=\"val"
  "ue_pos\">right</property></object><packing><property name=\"expand\">Tr"
  "ue</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">1</property></packing></child></object></child></object><packi"
  "ng><property name=\"expand\">True</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">1</property></packing></child><"
  "/object></child></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">False</property><property name=\"position\""
  ">1</property></packing></child></object></child><child type=\"label\"><"
  "object class=\"GtkLabel\" id=\"label5\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"label\" translatable=\"yes\">Bounce Keys</property><attributes><attri"
  "bute name=\"weight\" value=\"bold\"/></attributes></object></child></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"position\">2</property></packi"
  "ng></child></object></child></object></child></object><packing><propert"
  "y name=\"position\">1</property></packing></child><child type=\"tab\"><"
  "object class=\"GtkLabel\" id=\"label1\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"label\" translatable=\"yes\">Keyboa_rd</property><property name=\"use"
  "_underline\">True</property></object><packing><property name=\"position"
  "\">1</property><property name=\"tab_fill\">False</property></packing></"
  "child><child><object class=\"GtkScrolledWindow\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><child>"
  "<object class=\"GtkViewport\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><child><object class=\"Gt"
  "kBox\" id=\"vbox5\"><property name=\"visible\">True</property><property"
  " name=\"can_focus\">False</property><property name=\"border_width\">12<"
  "/property><property name=\"orientation\">vertical</property><property n"
  "ame=\"spacing\">18</property><child><object class=\"GtkFrame\" id=\"fra"
  "me4\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label_xalign\">0</property><prop"
  "erty name=\"shadow_type\">none</property><child><object class=\"GtkBox\""
  " id=\"mouse-emulation-box\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"margin_top"
  "\">6</property><property name=\"orientation\">vertical</property><prope"
  "rty name=\"spacing\">6</property><child><object class=\"GtkLabel\" id=\""
  "mouse-emulation-text\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"label\" transla"
  "table=\"yes\">When enabled, the mouse pointer can be controlled using t"
  "he keyboard number pad.</property><property name=\"wrap\">True</propert"
  "y><property name=\"xalign\">0</property></object><packing><property nam"
  "e=\"expand\">False</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">0</property></packing></child><child><object c"
  "lass=\"GtkAlignment\" id=\"mouse-emulation-alignment\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"left_padding\">12</property><child><object class=\"GtkB"
  "ox\" id=\"vbox8\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"orientation\">vertic"
  "al</property><property name=\"spacing\">6</property><child><object clas"
  "s=\"GtkCheckButton\" id=\"mouse-emulation-enabled\"><property name=\"la"
  "bel\" translatable=\"yes\">_Use mouse emulation</property><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">True</propert"
  "y><property name=\"receives_default\">False</property><property name=\""
  "tooltip_text\" translatable=\"yes\">When selected, the mouse pointer ca"
  "n be controlled using the keyboard number pad</property><property name="
  "\"halign\">start</property><property name=\"use_underline\">True</prope"
  "rty><property name=\"draw_indicator\">True</property></object><packing>"
  "<property name=\"expand\">False</property><property name=\"fill\">False"
  "</property><property name=\"position\">0</property></packing></child><c"
  "hild><object class=\"GtkAlignment\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"le"
  "ft_padding\">12</property><child><object class=\"GtkGrid\" id=\"mouse-e"
  "mulation-grid\"><property name=\"visible\">True</property><property nam"
  "e=\"sensitive\">False</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"row_spacing\">6</property><property name=\"colum"
  "n_spacing\">12</property><child><object class=\"GtkLabel\" id=\"label10"
  "\"><property name=\"visible\">True</property><property name=\"can_focus"
  "\">False</property><property name=\"halign\">start</property><property "
  "name=\"label\" translatable=\"yes\">msec</property></object><packing><p"
  "roperty name=\"left_attach\">2</property><property name=\"top_attach\">"
  "0</property></packing></child><child><object class=\"GtkSpinButton\" id"
  "=\"delay-widget\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">True</property><property name=\"tooltip_text\" transl"
  "atable=\"yes\">The time, in milliseconds, between the initial key press"
  " and first repeated motion event</property><property name=\"primary_ico"
  "n_activatable\">False</property><property name=\"secondary_icon_activat"
  "able\">False</property><property name=\"adjustment\">mouse-emulation-de"
  "lay</property><property name=\"numeric\">True</property><property name="
  "\"update_policy\">if-valid</property></object><packing><property name=\""
  "left_attach\">1</property><property name=\"top_attach\">0</property></p"
  "acking></child><child><object class=\"GtkLabel\" id=\"label7\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"halign\">start</property><property name=\"labe"
  "l\" translatable=\"yes\">_Acceleration delay:</property><property name="
  "\"use_underline\">True</property></object><packing><property name=\"lef"
  "t_attach\">0</property><property name=\"top_attach\">0</property></pack"
  "ing></child><child><object class=\"GtkLabel\" id=\"label16\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"halign\">start</property><property name=\"label\""
  " translatable=\"yes\">R_epeat interval:</property><property name=\"use_"
  "underline\">True</property></object><packing><property name=\"left_atta"
  "ch\">0</property><property name=\"top_attach\">1</property></packing></"
  "child><child><object class=\"GtkSpinButton\" id=\"interval-widget\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Tru"
  "e</property><property name=\"tooltip_text\" translatable=\"yes\">The ti"
  "me, in milliseconds, between repeated motion events</property><property"
  " name=\"primary_icon_activatable\">False</property><property name=\"sec"
  "ondary_icon_activatable\">False</property><property name=\"adjustment\""
  ">mouse-emulation-interval</property><property name=\"numeric\">True</pr"
  "operty><property name=\"update_policy\">if-valid</property></object><pa"
  "cking><property name=\"left_attach\">1</property><property name=\"top_a"
  "ttach\">1</property></packing></child><child><object class=\"GtkLabel\""
  " id=\"label11\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"halign\">start</proper"
  "ty><property name=\"label\" translatable=\"yes\">msec</property></objec"
  "t><packing><property name=\"left_attach\">2</property><property name=\""
  "top_attach\">1</property></packing></child><child><object class=\"GtkLa"
  "bel\" id=\"label19\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"halign\">start</p"
  "roperty><property name=\"label\" translatable=\"yes\">Acceleration t_im"
  "e:</property><property name=\"use_underline\">True</property></object><"
  "packing><property name=\"left_attach\">0</property><property name=\"top"
  "_attach\">2</property></packing></child><child><object class=\"GtkSpinB"
  "utton\" id=\"ttm-widget\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">True</property><property name=\"tooltip_text\""
  " translatable=\"yes\">The time, in milliseconds, to get to maximum spee"
  "d</property><property name=\"hexpand\">True</property><property name=\""
  "primary_icon_activatable\">False</property><property name=\"secondary_i"
  "con_activatable\">False</property><property name=\"adjustment\">mouse-e"
  "mulation-time-to-max</property><property name=\"numeric\">True</propert"
  "y><property name=\"update_policy\">if-valid</property></object><packing"
  "><property name=\"left_attach\">1</property><property name=\"top_attach"
  "\">2</property></packing></child><child><object class=\"GtkLabel\" id=\""
  "label13\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"halign\">start</property><pr"
  "operty name=\"label\" translatable=\"yes\">msec</property></object><pac"
  "king><property name=\"left_attach\">2</property><property name=\"top_at"
  "tach\">2</property></packing></child><child><object class=\"GtkLabel\" "
  "id=\"label22\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"halign\">start</propert"
  "y><property name=\"label\" translatable=\"yes\">Ma_ximum speed:</proper"
  "ty><property name=\"use_underline\">True</property></object><packing><p"
  "roperty name=\"left_attach\">0</property><property name=\"top_attach\">"
  "3</property></packing></child><child><object class=\"GtkSpinButton\" id"
  "=\"max-speed-widget\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property><property name=\"tooltip_text\" tr"
  "anslatable=\"yes\">The maximum pointer speed after acceleration</proper"
  "ty><property name=\"hexpand\">True</property><property name=\"primary_i"
  "con_activatable\">False</property><property name=\"secondary_icon_activ"
  "atable\">False</property><property name=\"adjustment\">mouse-emulation-"
  "max-speed</property><property name=\"numeric\">True</property><property"
  " name=\"update_policy\">if-valid</property></object><packing><property "
  "name=\"left_attach\">1</property><property name=\"top_attach\">3</prope"
  "rty></packing></child><child><object class=\"GtkLabel\" id=\"label15\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"halign\">start</property><property nam"
  "e=\"label\" translatable=\"yes\">pixels/sec</property></object><packing"
  "><property name=\"left_attach\">2</property><property name=\"top_attach"
  "\">3</property></packing></child><child><object class=\"GtkLabel\" id=\""
  "label8\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"halign\">start</property><pro"
  "perty name=\"label\" translatable=\"yes\">Acceleration _profile:</prope"
  "rty><property name=\"use_underline\">True</property></object><packing><"
  "property name=\"left_attach\">0</property><property name=\"top_attach\""
  ">4</property></packing></child><child><object class=\"GtkSpinButton\" i"
  "d=\"curve-widget\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">True</property><property name=\"tooltip_text\" trans"
  "latable=\"yes\">The ramp used to reach maximum pointer speed</property>"
  "<property name=\"primary_icon_activatable\">False</property><property n"
  "ame=\"secondary_icon_activatable\">False</property><property name=\"adj"
  "ustment\">mouse-emulation-curve</property><property name=\"numeric\">Tr"
  "ue</property><property name=\"update_policy\">if-valid</property></obje"
  "ct><packing><property name=\"left_attach\">1</property><property name=\""
  "top_attach\">4</property></packing></child><child><object class=\"GtkLa"
  "bel\" id=\"label14\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property></object><packing><property name=\""
  "left_attach\">2</property><property name=\"top_attach\">4</property></p"
  "acking></child></object></child></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">1</property></packing></child></object></child></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">True</property><property name=\"position\">1</property></packing>"
  "</child></object></child><child type=\"label\"><object class=\"GtkLabel"
  "\" id=\"label12\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"label\" translatable"
  "=\"yes\">Mouse Emulation</property><attributes><attribute name=\"weight"
  "\" value=\"bold\"/></attributes></object></child></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">True</pro"
  "perty><property name=\"position\">0</property></packing></child><child>"
  "<object class=\"GtkFrame\" id=\"find-cursor-frame\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"label_xalign\">0</property><property name=\"shadow_type\""
  ">none</property><child><object class=\"GtkBox\" id=\"find-cursor-box\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"margin_top\">6</property><property nam"
  "e=\"orientation\">vertical</property><property name=\"spacing\">6</prop"
  "erty><child><object class=\"GtkLabel\" id=\"find-cursor-text\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"label\" translatable=\"yes\">Bind a keyboard s"
  "hortcut to xfce4-find-cursor to get visual feedback of the mouse pointe"
  "r\'s current location.</property><property name=\"wrap\">True</property"
  "><property name=\"xalign\">0</property></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">0</property></packing></child><child><object cl"
  "ass=\"GtkAlignment\" id=\"find-cursor-alignment\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"left_padding\">12</property><child><object class=\"GtkCheck"
  "Button\" id=\"find-cursor\"><property name=\"label\" translatable=\"yes"
  "\">Show location of pointer on keypress</property><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"receives_default\">False</property><property name=\"halign\""
  ">start</property><property name=\"use_underline\">True</property><prope"
  "rty name=\"draw_indicator\">True</property></object></child></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">1</property></packing></chi"
  "ld></object></child><child type=\"label\"><object class=\"GtkLabel\" id"
  "=\"find-cursor-label\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"label\" transla"
  "table=\"yes\">Find Cursor</property><attributes><attribute name=\"weigh"
  "t\" value=\"bold\"/></attributes></object></child></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">True</pr"
  "operty><property name=\"position\">1</property></packing></child></obje"
  "ct></child></object></child></object><packing><property name=\"position"
  "\">2</property></packing></child><child type=\"tab\"><object class=\"Gt"
  "kLabel\" id=\"label2\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"label\" transla"
  "table=\"yes\">_Mouse</property><property name=\"use_underline\">True</p"
  "roperty></object><packing><property name=\"position\">2</property><prop"
  "erty name=\"tab_fill\">False</property></packing></child></object><pack"
  "ing><property name=\"expand\">True</property><property name=\"fill\">Tr"
  "ue</property><property name=\"position\">1</property></packing></child>"
  "</object><packing><property name=\"expand\">True</property><property na"
  "me=\"fill\">True</property><property name=\"position\">1</property></pa"
  "cking></child></object></child><action-widgets><action-widget response="
  "\"0\">button2</action-widget><action-widget response=\"-11\">button1</a"
  "ction-widget></action-widgets></object></interface>"
};

static const unsigned accessibility_dialog_ui_length = 37737u;

