/* automatically generated from color-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (color_dialog_ui)
#endif
#ifdef __GNUC__
static const char color_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char color_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.13\"/"
  "><object class=\"GtkListStore\" id=\"devices\"/><object class=\"GtkImag"
  "e\" id=\"image1\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">list-add"
  "-symbolic</property><property name=\"use_fallback\">True</property></ob"
  "ject><object class=\"GtkImage\" id=\"image2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"icon_name\">list-remove-symbolic</property><property name=\"use_"
  "fallback\">True</property></object><object class=\"GtkImage\" id=\"imag"
  "e3\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"icon_name\">folder-open-symbolic<"
  "/property></object><object class=\"GtkImage\" id=\"image4\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"icon_name\">dialog-information-symbolic</property"
  "></object><object class=\"GtkImage\" id=\"image5\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"icon_name\">dialog-information-symbolic</property></object"
  "><object class=\"GtkImage\" id=\"image6\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">help-browser</property></object><object class=\"GtkImag"
  "e\" id=\"image7\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">window-c"
  "lose-symbolic</property></object><object class=\"XfceTitledDialog\" id="
  "\"dialog\"><property name=\"can_focus\">False</property><property name="
  "\"title\" translatable=\"yes\">Color Profiles</property><property name="
  "\"window_position\">center-on-parent</property><property name=\"default"
  "_width\">700</property><property name=\"default_height\">400</property>"
  "<property name=\"icon_name\">org.xfce.settings.color</property><propert"
  "y name=\"type_hint\">dialog</property><child internal-child=\"vbox\"><o"
  "bject class=\"GtkBox\" id=\"dialog-vbox1\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"orientation\">vertical</property><property name=\"spacing\">2</pro"
  "perty><child internal-child=\"action_area\"><object class=\"GtkButtonBo"
  "x\" id=\"dialog-action_area1\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"layout_"
  "style\">end</property><child><object class=\"GtkButton\" id=\"button2\""
  "><property name=\"label\" translatable=\"yes\">_Close</property><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"receives_default\">True</property><property na"
  "me=\"image\">image7</property><property name=\"use_underline\">True</pr"
  "operty></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">False</property><property name=\"position\">0</prop"
  "erty></packing></child><child><object class=\"GtkButton\" id=\"button1\""
  "><property name=\"label\" translatable=\"yes\">_Help</property><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">True</pr"
  "operty><property name=\"receives_default\">True</property><property nam"
  "e=\"image\">image6</property><property name=\"use_underline\">True</pro"
  "perty></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">False</property><property name=\"position\">0</prope"
  "rty><property name=\"secondary\">True</property></packing></child></obj"
  "ect><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"pack_type\">end</property><prope"
  "rty name=\"position\">0</property></packing></child><child><object clas"
  "s=\"GtkBox\" id=\"plug-child\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"vexpand"
  "\">True</property><property name=\"orientation\">vertical</property><ch"
  "ild><object class=\"GtkPaned\" id=\"paned\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">True</property><property na"
  "me=\"margin_left\">6</property><property name=\"margin_right\">6</prope"
  "rty><property name=\"margin_top\">6</property><property name=\"margin_b"
  "ottom\">6</property><child><object class=\"GtkBox\" id=\"device\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"orientation\">vertical</property><child><ob"
  "ject class=\"GtkScrolledWindow\" id=\"scrolled-devices\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"hexpand\">True</property><property name=\"min_content"
  "_width\">250</property><child><placeholder/></child></object><packing><"
  "property name=\"expand\">True</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkBox\" id=\"label-no-devices\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"orientation\">vertical</property><child><object class=\"Gt"
  "kLabel\" id=\"label-no-devices-label\"><property name=\"visible\">True<"
  "/property><property name=\"sensitive\">False</property><property name=\""
  "can_focus\">False</property><property name=\"margin_left\">12</property"
  "><property name=\"margin_right\">12</property><property name=\"margin_t"
  "op\">12</property><property name=\"margin_bottom\">12</property><proper"
  "ty name=\"label\" translatable=\"yes\">&lt;b&gt;No devices found.&lt;/b"
  "&gt;</property><property name=\"use_markup\">True</property><property n"
  "ame=\"justify\">center</property></object><packing><property name=\"exp"
  "and\">False</property><property name=\"fill\">True</property><property "
  "name=\"position\">0</property></packing></child><style><class name=\"vi"
  "ew\"/><class name=\"frame\"/></style></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">1</property></packing></child></object><packing><p"
  "roperty name=\"resize\">False</property><property name=\"shrink\">False"
  "</property></packing></child><child><object class=\"GtkBox\" id=\"profi"
  "le\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"margin_left\">24</property><prope"
  "rty name=\"margin_right\">24</property><property name=\"margin_top\">18"
  "</property><property name=\"margin_bottom\">24</property><property name"
  "=\"orientation\">vertical</property><child><object class=\"GtkGrid\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"margin_top\">6</property><property name="
  "\"margin_bottom\">18</property><property name=\"row_spacing\">3</proper"
  "ty><property name=\"column_spacing\">12</property><child><object class="
  "\"GtkLabel\" id=\"model\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"xalign\">0</"
  "property></object><packing><property name=\"left_attach\">2</property><"
  "property name=\"top_attach\">0</property></packing></child><child><obje"
  "ct class=\"GtkLabel\" id=\"colorspace\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"xalign\">0</property></object><packing><property name=\"left_attach\""
  ">2</property><property name=\"top_attach\">2</property></packing></chil"
  "d><child><object class=\"GtkLabel\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"la"
  "bel\" translatable=\"yes\">Model:</property><property name=\"xalign\">1"
  "</property></object><packing><property name=\"left_attach\">1</property"
  "><property name=\"top_attach\">0</property></packing></child><child><ob"
  "ject class=\"GtkLabel\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"label\" transl"
  "atable=\"yes\">Colorspace:</property><property name=\"xalign\">1</prope"
  "rty></object><packing><property name=\"left_attach\">1</property><prope"
  "rty name=\"top_attach\">2</property></packing></child><child><object cl"
  "ass=\"GtkLabel\" id=\"vendor\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"xalign\""
  ">0</property></object><packing><property name=\"left_attach\">2</proper"
  "ty><property name=\"top_attach\">1</property></packing></child><child><"
  "object class=\"GtkLabel\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"label\" tran"
  "slatable=\"yes\">Vendor:</property><property name=\"xalign\">1</propert"
  "y></object><packing><property name=\"left_attach\">1</property><propert"
  "y name=\"top_attach\">1</property></packing></child><child><object clas"
  "s=\"GtkImage\" id=\"device-icon\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"marg"
  "in_right\">12</property><property name=\"pixel_size\">64</property><pro"
  "perty name=\"icon_size\">3</property></object><packing><property name=\""
  "left_attach\">0</property><property name=\"top_attach\">0</property><pr"
  "operty name=\"height\">3</property></packing></child><child><object cla"
  "ss=\"GtkButton\" id=\"device-calibrate\"><property name=\"label\" trans"
  "latable=\"yes\">Calibrate</property><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">True</property><property name=\"rec"
  "eives_default\">True</property><property name=\"halign\">start</propert"
  "y><property name=\"margin_top\">6</property></object><packing><property"
  " name=\"left_attach\">1</property><property name=\"top_attach\">3</prop"
  "erty></packing></child><child><placeholder/></child><child><placeholder"
  "/></child></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">True</property><property name=\"position\">0</pr"
  "operty></packing></child><child><object class=\"GtkScrolledWindow\" id="
  "\"scrolled-profiles\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property><property name=\"vexpand\">True</p"
  "roperty><property name=\"shadow_type\">in</property><child><placeholder"
  "/></child></object><packing><property name=\"expand\">True</property><p"
  "roperty name=\"fill\">True</property><property name=\"position\">1</pro"
  "perty></packing></child><child><object class=\"GtkBox\" id=\"label-no-p"
  "rofiles\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"hexpand\">True</property><pr"
  "operty name=\"orientation\">vertical</property><child><object class=\"G"
  "tkLabel\" id=\"label-no-profiles-label\"><property name=\"visible\">Tru"
  "e</property><property name=\"sensitive\">False</property><property name"
  "=\"can_focus\">False</property><property name=\"margin_left\">11</prope"
  "rty><property name=\"margin_right\">11</property><property name=\"margi"
  "n_top\">11</property><property name=\"margin_bottom\">11</property><pro"
  "perty name=\"vexpand\">True</property><property name=\"label\" translat"
  "able=\"yes\">&lt;b&gt;No profiles for the selected device.&lt;/b&gt;</p"
  "roperty><property name=\"use_markup\">True</property><property name=\"j"
  "ustify\">center</property></object><packing><property name=\"expand\">T"
  "rue</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">0</property></packing></child><style><class name=\"view\"/><c"
  "lass name=\"frame\"/></style></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">2</property></packing></child><child><object class=\"GtkFr"
  "ame\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label_xalign\">0</property><prop"
  "erty name=\"shadow_type\">none</property><child><object class=\"GtkBox\""
  " id=\"profiles-toolbar\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><child><object class=\"GtkBox\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><child><object class=\"GtkButton\" id=\"profiles-add\""
  "><property name=\"label\" translatable=\"yes\">_Add</property><property"
  " name=\"visible\">True</property><property name=\"can_focus\">True</pro"
  "perty><property name=\"receives_default\">True</property><property name"
  "=\"tooltip_text\" translatable=\"yes\">Add a profile to the currently s"
  "elected device</property><property name=\"image\">image1</property><pro"
  "perty name=\"use_underline\">True</property></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">0</property></packing></child><child><obje"
  "ct class=\"GtkButton\" id=\"profiles-remove\"><property name=\"label\" "
  "translatable=\"yes\">_Remove</property><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "receives_default\">True</property><property name=\"tooltip_text\" trans"
  "latable=\"yes\">Delete the currently selected profile</property><proper"
  "ty name=\"image\">image2</property><property name=\"use_underline\">Tru"
  "e</property></object><packing><property name=\"expand\">False</property"
  "><property name=\"fill\">True</property><property name=\"position\">1</"
  "property></packing></child><child><object class=\"GtkButton\" id=\"prof"
  "iles-info\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">True</pr"
  "operty><property name=\"tooltip_text\" translatable=\"yes\">Show detail"
  "ed information about the selected profile</property><property name=\"im"
  "age\">image4</property></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">2</property></packing></child></object><packing><property name="
  "\"expand\">False</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">0</property></packing></child><child><object cla"
  "ss=\"GtkBox\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"orientation\">vertical</"
  "property><child><object class=\"GtkButton\" id=\"profiles-enable\"><pro"
  "perty name=\"label\" translatable=\"yes\">Enable</property><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">True</proper"
  "ty><property name=\"receives_default\">True</property><property name=\""
  "tooltip_text\" translatable=\"yes\">Enable the selected profile</proper"
  "ty></object><packing><property name=\"expand\">False</property><propert"
  "y name=\"fill\">True</property><property name=\"position\">0</property>"
  "</packing></child></object><packing><property name=\"expand\">False</pr"
  "operty><property name=\"fill\">True</property><property name=\"pack_typ"
  "e\">end</property><property name=\"position\">2</property></packing></c"
  "hild></object></child><child type=\"label_item\"><placeholder/></child>"
  "<style><class name=\"inline-toolbar\"/></style></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">3</property></packing></child></object>"
  "<packing><property name=\"resize\">True</property><property name=\"shri"
  "nk\">False</property></packing></child><style><class name=\"frame\"/></"
  "style></object><packing><property name=\"expand\">True</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">0</propert"
  "y></packing></child></object><packing><property name=\"expand\">True</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">1</property></packing></child></object></child><action-widgets><act"
  "ion-widget response=\"0\">button2</action-widget><action-widget respons"
  "e=\"-11\">button1</action-widget></action-widgets></object><object clas"
  "s=\"GtkListStore\" id=\"liststore-assign\"><columns><column type=\"gcha"
  "rarray\"/><column type=\"GObject\"/><column type=\"guint\"/><column typ"
  "e=\"gchararray\"/></columns></object><object class=\"XfceTitledDialog\""
  " id=\"dialog-assign\"><property name=\"can_focus\">False</property><pro"
  "perty name=\"title\" translatable=\"yes\">Add Profile to Device</proper"
  "ty><property name=\"modal\">True</property><property name=\"default_wid"
  "th\">350</property><property name=\"default_height\">500</property><pro"
  "perty name=\"icon_name\">xfce4-color-settings</property><property name="
  "\"type_hint\">dialog</property><property name=\"transient_for\">dialog<"
  "/property><child internal-child=\"vbox\"><object class=\"GtkBox\"><prop"
  "erty name=\"can_focus\">False</property><property name=\"orientation\">"
  "vertical</property><property name=\"spacing\">2</property><child intern"
  "al-child=\"action_area\"><object class=\"GtkButtonBox\"><property name="
  "\"can_focus\">False</property><property name=\"layout_style\">end</prop"
  "erty><child><object class=\"GtkButton\" id=\"assign-cancel\"><property "
  "name=\"label\" translatable=\"yes\">_Cancel</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">True</property><property name=\"use_u"
  "nderline\">True</property></object><packing><property name=\"expand\">T"
  "rue</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">0</property></packing></child><child><object class=\"GtkButto"
  "n\" id=\"assign-ok\"><property name=\"label\" translatable=\"yes\">_OK<"
  "/property><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">True</property><property name=\"receives_default\">True</prop"
  "erty><property name=\"use_underline\">True</property></object><packing>"
  "<property name=\"expand\">True</property><property name=\"fill\">True</"
  "property><property name=\"position\">1</property></packing></child></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">False</property><property name=\"position\">0</property></pack"
  "ing></child><child><object class=\"GtkBox\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"margin_left\">12</property><property name=\"margin_right\">12</pr"
  "operty><property name=\"margin_top\">12</property><property name=\"orie"
  "ntation\">vertical</property><child><object class=\"GtkScrolledWindow\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"shadow_type\">in</property><child><obj"
  "ect class=\"GtkTreeView\" id=\"treeview-assign\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"model\">liststore-assign</property><child internal-child=\"se"
  "lection\"><object class=\"GtkTreeSelection\"/></child></object></child>"
  "</object><packing><property name=\"expand\">True</property><property na"
  "me=\"fill\">True</property><property name=\"position\">0</property></pa"
  "cking></child><child><object class=\"GtkBox\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"margin_bottom\">12</property><child><object class=\"GtkButton\" "
  "id=\"assign-import\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">True</property><property name=\"receives_default\""
  ">True</property><property name=\"tooltip_text\" translatable=\"yes\">Im"
  "port color profile files (*.icc)</property><property name=\"halign\">st"
  "art</property><property name=\"image\">image3</property></object><packi"
  "ng><property name=\"expand\">False</property><property name=\"fill\">Fa"
  "lse</property><property name=\"position\">0</property></packing></child"
  "><child><object class=\"GtkButton\" id=\"assign-info\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">True</property><property name=\"toolt"
  "ip_text\" translatable=\"yes\">Show detailed information about the sele"
  "cted profile</property><property name=\"image\">image5</property></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">True</property><property name=\"position\">1</property></packing"
  "></child><style><class name=\"inline-toolbar\"/></style></object><packi"
  "ng><property name=\"expand\">False</property><property name=\"fill\">Tr"
  "ue</property><property name=\"position\">1</property></packing></child>"
  "</object><packing><property name=\"expand\">True</property><property na"
  "me=\"fill\">True</property><property name=\"position\">1</property></pa"
  "cking></child></object></child></object><object class=\"GtkListStore\" "
  "id=\"profiles\"/></interface>"
};

static const unsigned color_dialog_ui_length = 19401u;

