/* automatically generated from identity-popup.glade */
#ifdef __SUNPRO_C
#pragma align 4 (identity_popup_ui)
#endif
#ifdef __GNUC__
static const char identity_popup_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char identity_popup_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><object class=\"GtkWindow\" id=\"popup\"><proper"
  "ty name=\"can_focus\">False</property><property name=\"type\">popup</pr"
  "operty><property name=\"default_height\">64</property><property name=\""
  "type_hint\">notification</property><property name=\"gravity\">south</pr"
  "operty><child><placeholder/></child><child><object class=\"GtkBox\" id="
  "\"hbox1\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"border_width\">6</property><"
  "property name=\"spacing\">12</property><child><object class=\"GtkLabel\""
  " id=\"display_number\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property><property name=\"valign\">center"
  "</property><property name=\"margin_left\">12</property><property name=\""
  "margin_right\">6</property><property name=\"label\">&lt;span size=\"xx-"
  "large\"&gt;&lt;b&gt;1&lt;/b&gt;&lt;/span&gt;</property><property name=\""
  "use_markup\">True</property><property name=\"xalign\">0.5</property><pr"
  "operty name=\"yalign\">0.5</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">0</property></packing></child><child><object class"
  "=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"valign\">cent"
  "er</property><property name=\"margin_right\">12</property><property nam"
  "e=\"orientation\">vertical</property><property name=\"spacing\">3</prop"
  "erty><child><object class=\"GtkLabel\" id=\"display_name\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"label\">&lt;big&gt;&lt;b&gt;Display: Name&lt;/b&gt"
  ";&lt;/big&gt;</property><property name=\"use_markup\">True</property><p"
  "roperty name=\"xalign\">0</property></object><packing><property name=\""
  "expand\">True</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">0</property></packing></child><child><object class="
  "\"GtkLabel\" id=\"display_details\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"la"
  "bel\">Resolution: 1280 x 800</property><property name=\"xalign\">0</pro"
  "perty></object><packing><property name=\"expand\">True</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">1</propert"
  "y></packing></child></object><packing><property name=\"expand\">True</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">1</property></packing></child></object></child></object></interface"
  ">"
};

static const unsigned identity_popup_ui_length = 2508u;

