/* automatically generated from mouse-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (mouse_dialog_ui)
#endif
#ifdef __GNUC__
static const char mouse_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char mouse_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.13\"/"
  "><object class=\"GtkAdjustment\" id=\"dclick-distance\"><property name="
  "\"upper\">20</property><property name=\"value\">4</property><property n"
  "ame=\"step_increment\">1</property><property name=\"page_increment\">5<"
  "/property></object><object class=\"GtkAdjustment\" id=\"dclick-time\"><"
  "property name=\"lower\">100</property><property name=\"upper\">2000</pr"
  "operty><property name=\"value\">250</property><property name=\"step_inc"
  "rement\">1</property><property name=\"page_increment\">100</property></"
  "object><object class=\"GtkAdjustment\" id=\"device-acceleration\"><prop"
  "erty name=\"upper\">10</property><property name=\"value\">2</property><"
  "property name=\"step_increment\">0.10000000000000001</property><propert"
  "y name=\"page_increment\">1</property></object><object class=\"GtkAdjus"
  "tment\" id=\"device-threshold\"><property name=\"lower\">1</property><p"
  "roperty name=\"upper\">30</property><property name=\"value\">4</propert"
  "y><property name=\"step_increment\">1</property><property name=\"page_i"
  "ncrement\">5</property></object><object class=\"GtkAdjustment\" id=\"dn"
  "d-threshold\"><property name=\"lower\">1</property><property name=\"upp"
  "er\">50</property><property name=\"value\">8</property><property name=\""
  "step_increment\">1</property><property name=\"page_increment\">10</prop"
  "erty></object><object class=\"GtkImage\" id=\"image1\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"icon_name\">window-close-symbolic</property></object><o"
  "bject class=\"GtkImage\" id=\"image2\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "icon_name\">help-browser</property></object><object class=\"GtkImage\" "
  "id=\"image5\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"stock\">gtk-revert-to-sa"
  "ved</property></object><object class=\"GtkAdjustment\" id=\"synaptics-d"
  "isable-duration\"><property name=\"lower\">0.10000000000000001</propert"
  "y><property name=\"upper\">4</property><property name=\"value\">2</prop"
  "erty><property name=\"step_increment\">0.10000000000000001</property><p"
  "roperty name=\"page_increment\">1</property></object><object class=\"Gt"
  "kListStore\" id=\"synaptics-scroll-store\"><columns><column type=\"gcha"
  "rarray\"/><column type=\"gboolean\"/></columns><data><row><col id=\"0\""
  " translatable=\"yes\">Disabled</col><col id=\"1\">True</col></row><row>"
  "<col id=\"0\" translatable=\"yes\">Edge scrolling</col><col id=\"1\">Tr"
  "ue</col></row><row><col id=\"0\" translatable=\"yes\">Two-finger scroll"
  "ing</col><col id=\"1\">True</col></row><row><col id=\"0\" translatable="
  "\"yes\">Circular scrolling</col><col id=\"1\">True</col></row></data></"
  "object><object class=\"GtkAdjustment\" id=\"theme-cursor-size\"><proper"
  "ty name=\"lower\">16</property><property name=\"upper\">72</property><p"
  "roperty name=\"value\">24</property><property name=\"step_increment\">1"
  "</property><property name=\"page_increment\">11</property></object><obj"
  "ect class=\"GtkListStore\" id=\"wacom-mode-store\"><columns><column typ"
  "e=\"gchararray\"/><column type=\"gchararray\"/></columns><data><row><co"
  "l id=\"0\">ABSOLUTE</col><col id=\"1\" translatable=\"yes\">Pen (absolu"
  "te)</col></row><row><col id=\"0\">RELATIVE</col><col id=\"1\" translata"
  "ble=\"yes\">Mouse (relative)</col></row></data></object><object class=\""
  "GtkListStore\" id=\"wacom-rotation-store\"><columns><column type=\"gint"
  "\"/><column type=\"gchararray\"/></columns><data><row><col id=\"0\">0</"
  "col><col id=\"1\" translatable=\"yes\">None (right-handed)</col></row><"
  "row><col id=\"0\">3</col><col id=\"1\" translatable=\"yes\">Half (left-"
  "handed)</col></row><row><col id=\"0\">1</col><col id=\"1\" translatable"
  "=\"yes\">Clockwise</col></row><row><col id=\"0\">2</col><col id=\"1\" t"
  "ranslatable=\"yes\">Counterclockwise</col></row></data></object><object"
  " class=\"XfceTitledDialog\" id=\"mouse-dialog\"><property name=\"can_fo"
  "cus\">False</property><property name=\"title\" translatable=\"yes\">Mou"
  "se and Touchpad</property><property name=\"window_position\">center-on-"
  "parent</property><property name=\"icon_name\">org.xfce.settings.mouse</"
  "property><property name=\"type_hint\">dialog</property><child internal-"
  "child=\"vbox\"><object class=\"GtkBox\" id=\"dialog-vbox1\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"orientation\">vertical</property><property name=\""
  "spacing\">2</property><child internal-child=\"action_area\"><object cla"
  "ss=\"GtkButtonBox\" id=\"dialog-action_area1\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"layout_style\">end</property><child><object class=\"GtkButton\""
  " id=\"button2\"><property name=\"label\" translatable=\"yes\">_Help</pr"
  "operty><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">True</property><property name=\"receives_default\">True</propert"
  "y><property name=\"image\">image2</property><property name=\"use_underl"
  "ine\">True</property></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">False</property><property name=\"posi"
  "tion\">0</property><property name=\"secondary\">True</property></packin"
  "g></child><child><object class=\"GtkButton\" id=\"button1\"><property n"
  "ame=\"label\" translatable=\"yes\">_Close</property><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">True</property><pro"
  "perty name=\"receives_default\">True</property><property name=\"image\""
  ">image1</property><property name=\"use_underline\">True</property></obj"
  "ect><packing><property name=\"expand\">False</property><property name=\""
  "fill\">False</property><property name=\"position\">0</property></packin"
  "g></child></object><packing><property name=\"expand\">False</property><"
  "property name=\"fill\">True</property><property name=\"pack_type\">end<"
  "/property><property name=\"position\">0</property></packing></child><ch"
  "ild><object class=\"GtkNotebook\" id=\"plug-child\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">True</property><pro"
  "perty name=\"border_width\">6</property><child><object class=\"GtkBox\""
  " id=\"vbox1\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"border_width\">12</prope"
  "rty><property name=\"orientation\">vertical</property><property name=\""
  "spacing\">12</property><child><object class=\"GtkBox\" id=\"hbox1\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"spacing\">12</property><child><object cla"
  "ss=\"GtkLabel\" id=\"label7\"><property name=\"visible\">True</property"
  "><property name=\"can_focus\">False</property><property name=\"label\" "
  "translatable=\"yes\">De_vice:</property><property name=\"use_underline\""
  ">True</property><property name=\"mnemonic_widget\">device-combobox</pro"
  "perty><property name=\"angle\">0.050000000000000003</property></object>"
  "<packing><property name=\"expand\">False</property><property name=\"fil"
  "l\">True</property><property name=\"position\">0</property></packing></"
  "child><child><object class=\"GtkComboBox\" id=\"device-combobox\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property></object><packing><property name=\"expand\">True</property><"
  "property name=\"fill\">True</property><property name=\"position\">1</pr"
  "operty></packing></child><child><object class=\"GtkSwitch\" id=\"device"
  "-enabled\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">True</property><property name=\"valign\">center</property></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">True</property><property name=\"position\">2</property></pac"
  "king></child></object><packing><property name=\"expand\">False</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">0<"
  "/property></packing></child><child><object class=\"GtkNotebook\" id=\"d"
  "evice-notebook\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">True</property><child><object class=\"GtkBox\" id=\"de"
  "vice-box\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">False</property><property name=\"border_width\">12</property"
  "><property name=\"orientation\">vertical</property><property name=\"spa"
  "cing\">18</property><child><object class=\"GtkFrame\" id=\"frame1\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"label_xalign\">0</property><property name"
  "=\"shadow_type\">none</property><child><object class=\"GtkAlignment\" i"
  "d=\"alignment1\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"top_padding\">6</prop"
  "erty><property name=\"left_padding\">12</property><child><object class="
  "\"GtkBox\" id=\"vbox12\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"orientation\""
  ">vertical</property><property name=\"spacing\">6</property><child><obje"
  "ct class=\"GtkBox\" id=\"hbox3\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"spaci"
  "ng\">12</property><child><object class=\"GtkRadioButton\" id=\"device-l"
  "eft-handed\"><property name=\"label\" translatable=\"yes\">Le_ft-handed"
  "</property><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">True</property><property name=\"receives_default\">False</pr"
  "operty><property name=\"halign\">start</property><property name=\"use_u"
  "nderline\">True</property><property name=\"draw_indicator\">True</prope"
  "rty><property name=\"group\">device-right-handed</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkRadioButton\" id=\"device-right-handed\"><"
  "property name=\"label\" translatable=\"yes\">Ri_ght-handed</property><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Tr"
  "ue</property><property name=\"receives_default\">False</property><prope"
  "rty name=\"halign\">start</property><property name=\"use_underline\">Tr"
  "ue</property><property name=\"active\">True</property><property name=\""
  "draw_indicator\">True</property></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">1</property></packing></child></object><packing><prope"
  "rty name=\"expand\">True</property><property name=\"fill\">True</proper"
  "ty><property name=\"position\">0</property></packing></child><child><ob"
  "ject class=\"GtkCheckButton\" id=\"device-reverse-scrolling\"><property"
  " name=\"label\" translatable=\"yes\">Reverse scroll d_irection</propert"
  "y><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"receives_default\">False</property><pr"
  "operty name=\"tooltip_text\" translatable=\"yes\">When selected, the sc"
  "roll wheel will work in the opposite direction</property><property name"
  "=\"halign\">start</property><property name=\"use_underline\">True</prop"
  "erty><property name=\"draw_indicator\">True</property></object><packing"
  "><property name=\"expand\">True</property><property name=\"fill\">True<"
  "/property><property name=\"position\">1</property></packing></child></o"
  "bject></child></object></child><child type=\"label\"><object class=\"Gt"
  "kLabel\" id=\"label14\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"label\" transl"
  "atable=\"yes\">Buttons</property><attributes><attribute name=\"weight\""
  " value=\"bold\"/></attributes></object></child></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">0</property></packing></child><child><o"
  "bject class=\"GtkFrame\" id=\"frame2\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "label_xalign\">0</property><property name=\"shadow_type\">none</propert"
  "y><child><object class=\"GtkAlignment\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"top_padding\">6</property><property name=\"left_padding\">12</propert"
  "y><child><object class=\"GtkGrid\" id=\"grid1\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"row_spacing\">6</property><property name=\"column_spacing\">1"
  "2</property><child><object class=\"GtkButton\" id=\"device-reset-feedba"
  "ck\"><property name=\"label\" translatable=\"yes\">_Reset to Defaults</"
  "property><property name=\"visible\">True</property><property name=\"can"
  "_focus\">True</property><property name=\"receives_default\">True</prope"
  "rty><property name=\"tooltip_text\" translatable=\"yes\">Set the accele"
  "ration and sensitivity for the selected device to the default values</p"
  "roperty><property name=\"halign\">start</property><property name=\"imag"
  "e\">image5</property><property name=\"use_underline\">True</property></"
  "object><packing><property name=\"left_attach\">0</property><property na"
  "me=\"top_attach\">2</property><property name=\"width\">2</property></pa"
  "cking></child><child><object class=\"GtkLabel\" id=\"device-threshold-l"
  "abel\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"halign\">start</property><prope"
  "rty name=\"label\" translatable=\"yes\">Sensitivit_y:</property><proper"
  "ty name=\"use_underline\">True</property></object><packing><property na"
  "me=\"left_attach\">0</property><property name=\"top_attach\">1</propert"
  "y></packing></child><child><object class=\"GtkLabel\" id=\"device-accel"
  "eration-label\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"halign\">start</proper"
  "ty><property name=\"label\" translatable=\"yes\">Acceleratio_n:</proper"
  "ty><property name=\"use_underline\">True</property></object><packing><p"
  "roperty name=\"left_attach\">0</property><property name=\"top_attach\">"
  "0</property></packing></child><child><object class=\"GtkScale\" id=\"de"
  "vice-acceleration-scale\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">True</property><property name=\"tooltip_text\""
  " translatable=\"yes\">The factor at which the pointer\'s speed will inc"
  "rease as the mouse is moved</property><property name=\"hexpand\">True</"
  "property><property name=\"adjustment\">device-acceleration</property><p"
  "roperty name=\"round_digits\">1</property><property name=\"value_pos\">"
  "right</property></object><packing><property name=\"left_attach\">1</pro"
  "perty><property name=\"top_attach\">0</property></packing></child><chil"
  "d><object class=\"GtkScale\" id=\"device-threshold-scale\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">True</proper"
  "ty><property name=\"tooltip_text\" translatable=\"yes\">The number of p"
  "ixels the pointer must move in a short time before it starts accelerati"
  "ng</property><property name=\"hexpand\">True</property><property name=\""
  "adjustment\">device-threshold</property><property name=\"round_digits\""
  ">0</property><property name=\"digits\">0</property><property name=\"val"
  "ue_pos\">right</property></object><packing><property name=\"left_attach"
  "\">1</property><property name=\"top_attach\">1</property></packing></ch"
  "ild></object></child></object></child><child type=\"label\"><object cla"
  "ss=\"GtkLabel\" id=\"label15\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"label\""
  " translatable=\"yes\">Pointer Speed</property><attributes><attribute na"
  "me=\"weight\" value=\"bold\"/></attributes></object></child></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">1</property></packing></chi"
  "ld></object></child><child type=\"tab\"><object class=\"GtkLabel\" id=\""
  "label4\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "B_uttons and Feedback</property><property name=\"use_underline\">True</"
  "property></object><packing><property name=\"tab_fill\">False</property>"
  "</packing></child><child><object class=\"GtkBox\" id=\"synaptics-tab\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"border_width\">12</property><property "
  "name=\"orientation\">vertical</property><property name=\"spacing\">18</"
  "property><child><object class=\"GtkFrame\" id=\"frame11\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"label_xalign\">0</property><property name=\"shadow_"
  "type\">none</property><child><object class=\"GtkAlignment\" id=\"alignm"
  "ent13\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"top_padding\">6</property><pro"
  "perty name=\"left_padding\">12</property><child><object class=\"GtkBox\""
  " id=\"vbox11\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"orientation\">vertical<"
  "/property><property name=\"spacing\">6</property><child><object class=\""
  "GtkCheckButton\" id=\"synaptics-disable-while-type\"><property name=\"l"
  "abel\" translatable=\"yes\">Disable touchpad _while typing</property><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Tr"
  "ue</property><property name=\"receives_default\">False</property><prope"
  "rty name=\"tooltip_text\" translatable=\"yes\">When selected, the touch"
  "pad will be disabled when the keyboard is being used</property><propert"
  "y name=\"halign\">start</property><property name=\"use_underline\">True"
  "</property><property name=\"draw_indicator\">True</property></object><p"
  "acking><property name=\"expand\">True</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkAlignment\" id=\"alignment8\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"left_padding\">12</property><child><object class=\""
  "GtkBox\" id=\"synaptics-disable-duration-box\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"spacing\">12</property><child><object class=\"GtkLabel\" id=\""
  "label5\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"label\" translatable=\"yes\">"
  "Duratio_n:</property><property name=\"use_underline\">True</property><p"
  "roperty name=\"mnemonic_widget\">synaptics-disable-duration-scale</prop"
  "erty></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">0</propert"
  "y></packing></child><child><object class=\"GtkScale\" id=\"synaptics-di"
  "sable-duration-scale\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">True</property><property name=\"adjustment\">syn"
  "aptics-disable-duration</property><property name=\"round_digits\">1</pr"
  "operty><property name=\"value_pos\">right</property></object><packing><"
  "property name=\"expand\">True</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">1</property></packing></child></obj"
  "ect></child></object><packing><property name=\"expand\">True</property>"
  "<property name=\"fill\">True</property><property name=\"position\">1</p"
  "roperty></packing></child><child><object class=\"GtkCheckButton\" id=\""
  "synaptics-tap-to-click\"><property name=\"label\" translatable=\"yes\">"
  "Tap touchpad to clic_k</property><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">True</property><property name=\"receiv"
  "es_default\">False</property><property name=\"halign\">start</property>"
  "<property name=\"use_underline\">True</property><property name=\"draw_i"
  "ndicator\">True</property></object><packing><property name=\"expand\">T"
  "rue</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">2</property></packing></child></object></child></object></chi"
  "ld><child type=\"label\"><object class=\"GtkLabel\" id=\"label16\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"label\" translatable=\"yes\">General</prop"
  "erty><property name=\"use_markup\">True</property><attributes><attribut"
  "e name=\"weight\" value=\"bold\"/></attributes></object></child></objec"
  "t><packing><property name=\"expand\">False</property><property name=\"f"
  "ill\">True</property><property name=\"position\">0</property></packing>"
  "</child><child><object class=\"GtkFrame\" id=\"frame10\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y><property name=\"label_xalign\">0</property><property name=\"shadow_t"
  "ype\">none</property><child><object class=\"GtkAlignment\" id=\"alignme"
  "nt12\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"top_padding\">6</property><prop"
  "erty name=\"left_padding\">12</property><child><object class=\"GtkBox\""
  " id=\"vbox10\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"orientation\">vertical<"
  "/property><property name=\"spacing\">6</property><child><object class=\""
  "GtkBox\" id=\"hbox4\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"spacing\">12</pr"
  "operty><child><object class=\"GtkLabel\" id=\"label23\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"label\" translatable=\"yes\">Scrolling _mode:</proper"
  "ty><property name=\"use_underline\">True</property><property name=\"mne"
  "monic_widget\">synaptics-scroll</property></object><packing><property n"
  "ame=\"expand\">False</property><property name=\"fill\">True</property><"
  "property name=\"position\">0</property></packing></child><child><object"
  " class=\"GtkComboBox\" id=\"synaptics-scroll\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"model\">synaptics-scroll-store</property><child><object class="
  "\"GtkCellRendererText\" id=\"cellrenderertext3\"/><attributes><attribut"
  "e name=\"sensitive\">1</attribute><attribute name=\"text\">0</attribute"
  "></attributes></child></object><packing><property name=\"expand\">True<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">1</property></packing></child></object><packing><property name=\""
  "expand\">True</property><property name=\"fill\">True</property><propert"
  "y name=\"position\">0</property></packing></child><child><object class="
  "\"GtkCheckButton\" id=\"synaptics-scroll-horiz\"><property name=\"label"
  "\" translatable=\"yes\">Enable hori_zontal scrolling</property><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">True</pr"
  "operty><property name=\"receives_default\">False</property><property na"
  "me=\"halign\">start</property><property name=\"use_underline\">True</pr"
  "operty><property name=\"draw_indicator\">True</property></object><packi"
  "ng><property name=\"expand\">True</property><property name=\"fill\">Tru"
  "e</property><property name=\"position\">1</property></packing></child><"
  "/object></child></object></child><child type=\"label\"><object class=\""
  "GtkLabel\" id=\"label17\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"label\" tran"
  "slatable=\"yes\">Scrolling</property><property name=\"use_markup\">True"
  "</property><attributes><attribute name=\"weight\" value=\"bold\"/></att"
  "ributes></object></child></object><packing><property name=\"expand\">Fa"
  "lse</property><property name=\"fill\">True</property><property name=\"p"
  "osition\">1</property></packing></child></object><packing><property nam"
  "e=\"position\">1</property></packing></child><child type=\"tab\"><objec"
  "t class=\"GtkLabel\" id=\"synaptics-label\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label\" translatable=\"yes\">T_ouchpad</property><property name=\""
  "use_underline\">True</property></object><packing><property name=\"posit"
  "ion\">1</property><property name=\"tab_fill\">False</property></packing"
  "></child><child><object class=\"GtkBox\" id=\"wacom-tab\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"border_width\">12</property><property name=\"orient"
  "ation\">vertical</property><property name=\"spacing\">6</property><chil"
  "d><object class=\"GtkFrame\" id=\"frame12\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"label_xalign\">0</property><property name=\"shadow_type\">none</p"
  "roperty><child><object class=\"GtkAlignment\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"top_padding\">6</property><property name=\"left_padding\">12</pr"
  "operty><child><object class=\"GtkGrid\" id=\"grid2\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">False</property><p"
  "roperty name=\"row_spacing\">6</property><property name=\"column_spacin"
  "g\">12</property><child><object class=\"GtkLabel\" id=\"label9\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"halign\">start</property><property name=\"la"
  "bel\" translatable=\"yes\">Trac_king mode:</property><property name=\"u"
  "se_underline\">True</property></object><packing><property name=\"left_a"
  "ttach\">0</property><property name=\"top_attach\">0</property></packing"
  "></child><child><object class=\"GtkLabel\" id=\"label10\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"halign\">start</property><property name=\"label\" t"
  "ranslatable=\"yes\">_Rotation:</property><property name=\"use_underline"
  "\">True</property></object><packing><property name=\"left_attach\">0</p"
  "roperty><property name=\"top_attach\">1</property></packing></child><ch"
  "ild><object class=\"GtkComboBox\" id=\"wacom-mode\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"hexpand\">True</property><property name=\"model\">wacom-m"
  "ode-store</property><child><object class=\"GtkCellRendererText\" id=\"c"
  "ellrenderertext1\"/><attributes><attribute name=\"text\">1</attribute><"
  "/attributes></child></object><packing><property name=\"left_attach\">1<"
  "/property><property name=\"top_attach\">0</property></packing></child><"
  "child><object class=\"GtkComboBox\" id=\"wacom-rotation\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"hexpand\">True</property><property name=\"model\">w"
  "acom-rotation-store</property><child><object class=\"GtkCellRendererTex"
  "t\" id=\"cellrenderertext2\"/><attributes><attribute name=\"text\">1</a"
  "ttribute></attributes></child></object><packing><property name=\"left_a"
  "ttach\">1</property><property name=\"top_attach\">1</property></packing"
  "></child></object></child></object></child><child type=\"label\"><objec"
  "t class=\"GtkLabel\" id=\"label18\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"la"
  "bel\" translatable=\"yes\">General</property><property name=\"use_marku"
  "p\">True</property><attributes><attribute name=\"weight\" value=\"bold\""
  "/></attributes></object></child></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">0</property></packing></child></object><packing><prope"
  "rty name=\"position\">2</property></packing></child><child type=\"tab\""
  "><object class=\"GtkLabel\" id=\"wacom-label\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"label\" translatable=\"yes\">Tab_let</property><property name="
  "\"use_underline\">True</property></object><packing><property name=\"pos"
  "ition\">2</property><property name=\"tab_fill\">False</property></packi"
  "ng></child></object><packing><property name=\"expand\">True</property><"
  "property name=\"fill\">True</property><property name=\"position\">1</pr"
  "operty></packing></child></object></child><child type=\"tab\"><object c"
  "lass=\"GtkLabel\" id=\"label1\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"label\""
  " translatable=\"yes\">_Devices</property><property name=\"use_underline"
  "\">True</property></object><packing><property name=\"tab_fill\">False</"
  "property></packing></child><child><object class=\"GtkBox\" id=\"vbox3\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"border_width\">12</property><property"
  " name=\"orientation\">vertical</property><property name=\"spacing\">18<"
  "/property><child><object class=\"GtkFrame\" id=\"frame3\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"label_xalign\">0</property><property name=\"shadow_"
  "type\">none</property><child><object class=\"GtkAlignment\" id=\"alignm"
  "ent3\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"top_padding\">6</property><prop"
  "erty name=\"left_padding\">12</property><child><object class=\"GtkBox\""
  " id=\"vbox4\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"orientation\">vertical</"
  "property><property name=\"spacing\">6</property><child><object class=\""
  "GtkLabel\" id=\"mouse-dnd-label\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"hali"
  "gn\">start</property><property name=\"label\" translatable=\"yes\">Th_r"
  "eshold:</property><property name=\"use_underline\">True</property><prop"
  "erty name=\"mnemonic_widget\">dnd-threshold-scale</property></object><p"
  "acking><property name=\"expand\">True</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkScale\" id=\"dnd-threshold-scale\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"tooltip_text\" translatable=\"yes\">The number"
  " of pixels the pointer must move before a drag operation will start</pr"
  "operty><property name=\"adjustment\">dnd-threshold</property><property "
  "name=\"digits\">0</property><property name=\"value_pos\">right</propert"
  "y></object><packing><property name=\"expand\">True</property><property "
  "name=\"fill\">True</property><property name=\"position\">1</property></"
  "packing></child></object></child></object></child><child type=\"label\""
  "><object class=\"GtkLabel\" id=\"label6\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"label\" translatable=\"yes\">Drag and Drop</property><attributes><a"
  "ttribute name=\"weight\" value=\"bold\"/></attributes></object></child>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">0</property></p"
  "acking></child><child><object class=\"GtkFrame\" id=\"frame4\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"label_xalign\">0</property><property name=\"sh"
  "adow_type\">none</property><child><object class=\"GtkAlignment\" id=\"a"
  "lignment4\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"top_padding\">6</property>"
  "<property name=\"left_padding\">12</property><child><object class=\"Gtk"
  "Box\" id=\"vbox5\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"orientation\">verti"
  "cal</property><property name=\"spacing\">6</property><child><object cla"
  "ss=\"GtkLabel\" id=\"dclick-time-label\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"halign\">start</property><property name=\"label\" translatable=\"yes"
  "\">Ti_me:</property><property name=\"use_underline\">True</property><pr"
  "operty name=\"mnemonic_widget\">dclick-time-scale</property></object><p"
  "acking><property name=\"expand\">True</property><property name=\"fill\""
  ">True</property><property name=\"position\">0</property></packing></chi"
  "ld><child><object class=\"GtkScale\" id=\"dclick-time-scale\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">True</pro"
  "perty><property name=\"tooltip_text\" translatable=\"yes\">Two mouse cl"
  "icks in less than this length of time (in milliseconds) will be conside"
  "red a double click</property><property name=\"adjustment\">dclick-time<"
  "/property><property name=\"digits\">0</property><property name=\"value_"
  "pos\">right</property></object><packing><property name=\"expand\">True<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">1</property></packing></child><child><object class=\"GtkLabel\" i"
  "d=\"dclick-distance-label\"><property name=\"visible\">True</property><"
  "property name=\"can_focus\">False</property><property name=\"halign\">s"
  "tart</property><property name=\"label\" translatable=\"yes\">D_istance:"
  "</property><property name=\"use_underline\">True</property><property na"
  "me=\"mnemonic_widget\">dclick-distance-scale</property></object><packin"
  "g><property name=\"expand\">True</property><property name=\"fill\">True"
  "</property><property name=\"position\">2</property></packing></child><c"
  "hild><object class=\"GtkScale\" id=\"dclick-distance-scale\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">True</prop"
  "erty><property name=\"tooltip_text\" translatable=\"yes\">The mouse poi"
  "nter cannot move farther than this distance between two clicks for them"
  " to be considered a double click</property><property name=\"adjustment\""
  ">dclick-distance</property><property name=\"digits\">0</property><prope"
  "rty name=\"value_pos\">right</property></object><packing><property name"
  "=\"expand\">True</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">3</property></packing></child></object></child><"
  "/object></child><child type=\"label\"><object class=\"GtkLabel\" id=\"l"
  "abel8\"><property name=\"visible\">True</property><property name=\"can_"
  "focus\">False</property><property name=\"label\" translatable=\"yes\">D"
  "ouble Click</property><attributes><attribute name=\"weight\" value=\"bo"
  "ld\"/></attributes></object></child></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">True</property><proper"
  "ty name=\"position\">1</property></packing></child></object><packing><p"
  "roperty name=\"position\">1</property></packing></child><child type=\"t"
  "ab\"><object class=\"GtkLabel\" id=\"label2\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">_Behavior</property><property name="
  "\"use_underline\">True</property></object><packing><property name=\"pos"
  "ition\">1</property><property name=\"tab_fill\">False</property></packi"
  "ng></child><child><object class=\"GtkBox\" id=\"themes-hbox\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"border_width\">12</property><property name=\"sp"
  "acing\">12</property><child><object class=\"GtkScrolledWindow\" id=\"sc"
  "rolledwindow2\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">True</property><property name=\"shadow_type\">etched-in"
  "</property><child><object class=\"GtkTreeView\" id=\"theme-treeview\"><"
  "property name=\"width_request\">200</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"headers_visible\">False</property><child internal-child=\"selecti"
  "on\"><object class=\"GtkTreeSelection\" id=\"treeview-selection1\"/></c"
  "hild></object></child></object><packing><property name=\"expand\">True<"
  "/property><property name=\"fill\">True</property><property name=\"posit"
  "ion\">0</property></packing></child><child><object class=\"GtkBox\" id="
  "\"vbox9\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"orientation\">vertical</prop"
  "erty><property name=\"spacing\">18</property><child><object class=\"Gtk"
  "Frame\" id=\"frame5\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"label_xalign\">0"
  "</property><property name=\"shadow_type\">none</property><child><object"
  " class=\"GtkAlignment\" id=\"alignment5\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"top_padding\">6</property><property name=\"left_padding\">12</prope"
  "rty><child><object class=\"GtkBox\" id=\"hbox7\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"spacing\">12</property><child><object class=\"GtkLabel\" id="
  "\"label21\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"halign\">start</property><"
  "property name=\"label\" translatable=\"yes\">Cursor si_ze:</property><p"
  "roperty name=\"use_underline\">True</property><property name=\"mnemonic"
  "_widget\">spin1</property></object><packing><property name=\"expand\">F"
  "alse</property><property name=\"fill\">True</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkSpin"
  "Button\" id=\"spin1\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">True</property><property name=\"primary_icon_acti"
  "vatable\">False</property><property name=\"secondary_icon_activatable\""
  ">False</property><property name=\"adjustment\">theme-cursor-size</prope"
  "rty><property name=\"snap_to_ticks\">True</property><property name=\"nu"
  "meric\">True</property></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">1</property></packing></child></object></child></object></child"
  "><child type=\"label\"><object class=\"GtkLabel\" id=\"label20\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"label\" translatable=\"yes\">Size</property>"
  "<attributes><attribute name=\"weight\" value=\"bold\"/></attributes></o"
  "bject></child></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">True</property><property name=\"position\">0"
  "</property></packing></child><child><object class=\"GtkFrame\" id=\"fra"
  "me6\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label_xalign\">0</property><prop"
  "erty name=\"shadow_type\">none</property><child><object class=\"GtkAlig"
  "nment\" id=\"alignment6\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"border_width"
  "\">0</property><property name=\"xscale\">0</property><property name=\"y"
  "scale\">0</property><property name=\"top_padding\">6</property><child><"
  "object class=\"GtkImage\" id=\"theme-preview\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"stock\">gtk-missing-image</property></object></child></object>"
  "</child><child type=\"label\"><object class=\"GtkLabel\" id=\"label22\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"label\" translatable=\"yes\">Preview<"
  "/property><attributes><attribute name=\"weight\" value=\"bold\"/></attr"
  "ibutes></object></child></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">True</property><property name=\"po"
  "sition\">1</property></packing></child></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"position\">1</property></packing></child></object><packing"
  "><property name=\"position\">2</property></packing></child><child type="
  "\"tab\"><object class=\"GtkLabel\" id=\"label3\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"label\" translatable=\"yes\">_Theme</property><property name"
  "=\"use_underline\">True</property></object><packing><property name=\"po"
  "sition\">2</property><property name=\"tab_fill\">False</property></pack"
  "ing></child></object><packing><property name=\"expand\">True</property>"
  "<property name=\"fill\">True</property><property name=\"position\">1</p"
  "roperty></packing></child></object></child><action-widgets><action-widg"
  "et response=\"-11\">button2</action-widget><action-widget response=\"0\""
  ">button1</action-widget></action-widgets></object></interface>"
};

static const unsigned mouse_dialog_ui_length = 38481u;

