/* automatically generated from minimal-display-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (minimal_display_dialog_ui)
#endif
#ifdef __GNUC__
static const char minimal_display_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char minimal_display_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><object class=\"GtkImage\" id=\"image5\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"icon_name\">window-close-symbolic</property><"
  "/object><object class=\"GtkWindow\" id=\"dialog\"><property name=\"can_"
  "focus\">False</property><property name=\"title\" translatable=\"yes\">D"
  "isplays</property><property name=\"window_position\">center</property><"
  "property name=\"icon_name\">org.xfce.settings.display</property><proper"
  "ty name=\"type_hint\">dialog</property><child><placeholder/></child><ch"
  "ild><object class=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"border_width\">6</property><property name=\"orientation\">vertical<"
  "/property><property name=\"spacing\">6</property><child><object class=\""
  "GtkGrid\" id=\"buttons\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"row_spacing\""
  ">3</property><child><object class=\"GtkBox\" id=\"profile-box\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"hexpand\">True</property><child><placeholder/"
  "></child><child><placeholder/></child><child><placeholder/></child></ob"
  "ject><packing><property name=\"left_attach\">4</property><property name"
  "=\"top_attach\">0</property></packing></child><child><object class=\"Gt"
  "kBox\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"hexpand\">True</property><prope"
  "rty name=\"orientation\">vertical</property><property name=\"spacing\">"
  "3</property><child><object class=\"GtkRadioButton\" id=\"display1\"><pr"
  "operty name=\"width_request\">128</property><property name=\"height_req"
  "uest\">128</property><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">True</property><property name=\"receives_default\""
  ">False</property><property name=\"halign\">center</property><property n"
  "ame=\"active\">True</property><property name=\"draw_indicator\">False</"
  "property><child><object class=\"GtkImage\" id=\"image1\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y></object></child></object><packing><property name=\"expand\">False</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">0</property></packing></child><child><object class=\"GtkLabel\" id="
  "\"label1\"><property name=\"width_request\">128</property><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"label\" translatable=\"yes\">Only Display 1</proper"
  "ty><property name=\"ellipsize\">middle</property></object><packing><pro"
  "perty name=\"expand\">False</property><property name=\"fill\">True</pro"
  "perty><property name=\"position\">1</property></packing></child></objec"
  "t><packing><property name=\"left_attach\">0</property><property name=\""
  "top_attach\">0</property></packing></child><child><object class=\"GtkBo"
  "x\"><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">False</property><property name=\"margin_left\">24</property><proper"
  "ty name=\"hexpand\">True</property><property name=\"orientation\">verti"
  "cal</property><property name=\"spacing\">3</property><child><object cla"
  "ss=\"GtkRadioButton\" id=\"mirror\"><property name=\"width_request\">12"
  "8</property><property name=\"height_request\">128</property><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">True</prope"
  "rty><property name=\"receives_default\">False</property><property name="
  "\"halign\">center</property><property name=\"active\">True</property><p"
  "roperty name=\"draw_indicator\">False</property><property name=\"group\""
  ">display1</property><child><object class=\"GtkImage\" id=\"image2\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property></object></child></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">True</property><property nam"
  "e=\"position\">0</property></packing></child><child><object class=\"Gtk"
  "Label\" id=\"label2\"><property name=\"width_request\">128</property><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"tooltip_text\" translatable=\"yes\">Mirr"
  "or Displays</property><property name=\"label\" translatable=\"yes\">Mir"
  "ror Displays</property><property name=\"ellipsize\">middle</property></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">True</property><property name=\"position\">1</property></pac"
  "king></child></object><packing><property name=\"left_attach\">1</proper"
  "ty><property name=\"top_attach\">0</property></packing></child><child><"
  "object class=\"GtkBox\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"margin_left\">"
  "24</property><property name=\"hexpand\">True</property><property name=\""
  "orientation\">vertical</property><property name=\"spacing\">3</property"
  "><child><object class=\"GtkRadioButton\" id=\"extend_right\"><property "
  "name=\"width_request\">128</property><property name=\"height_request\">"
  "128</property><property name=\"visible\">True</property><property name="
  "\"can_focus\">True</property><property name=\"receives_default\">False<"
  "/property><property name=\"halign\">center</property><property name=\"a"
  "ctive\">True</property><property name=\"draw_indicator\">False</propert"
  "y><property name=\"group\">display1</property><child><object class=\"Gt"
  "kImage\" id=\"image3\"><property name=\"visible\">True</property><prope"
  "rty name=\"can_focus\">False</property></object></child></object><packi"
  "ng><property name=\"expand\">False</property><property name=\"fill\">Tr"
  "ue</property><property name=\"position\">0</property></packing></child>"
  "<child><object class=\"GtkLabel\" id=\"label3\"><property name=\"width_"
  "request\">128</property><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"tooltip_text\""
  " translatable=\"yes\">Extend to the right</property><property name=\"la"
  "bel\" translatable=\"yes\">Extend to the right</property><property name"
  "=\"ellipsize\">middle</property></object><packing><property name=\"expa"
  "nd\">False</property><property name=\"fill\">True</property><property n"
  "ame=\"position\">1</property></packing></child></object><packing><prope"
  "rty name=\"left_attach\">2</property><property name=\"top_attach\">0</p"
  "roperty></packing></child><child><object class=\"GtkBox\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"margin_left\">24</property><property name=\"hexpand"
  "\">True</property><property name=\"orientation\">vertical</property><pr"
  "operty name=\"spacing\">3</property><child><object class=\"GtkRadioButt"
  "on\" id=\"display2\"><property name=\"width_request\">128</property><pr"
  "operty name=\"height_request\">128</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">False</property><property name=\"halign\">cent"
  "er</property><property name=\"active\">True</property><property name=\""
  "draw_indicator\">False</property><property name=\"group\">display1</pro"
  "perty><child><object class=\"GtkImage\" id=\"image4\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "/object></child></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">True</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkLabel\" id=\"l"
  "abel4\"><property name=\"width_request\">128</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"label\" translatable=\"yes\">Only Display 2</property><"
  "property name=\"ellipsize\">middle</property></object><packing><propert"
  "y name=\"expand\">False</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">1</property></packing></child></object><p"
  "acking><property name=\"left_attach\">3</property><property name=\"top_"
  "attach\">0</property></packing></child></object><packing><property name"
  "=\"expand\">True</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">0</property></packing></child><child><object cla"
  "ss=\"GtkButtonBox\" id=\"hbuttonbox1\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><child><object c"
  "lass=\"GtkButton\" id=\"advanced_button\"><property name=\"label\" tran"
  "slatable=\"yes\">_Advanced</property><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">True</property><property name=\"re"
  "ceives_default\">True</property><property name=\"use_underline\">True</"
  "property></object><packing><property name=\"expand\">False</property><p"
  "roperty name=\"fill\">False</property><property name=\"position\">0</pr"
  "operty></packing></child><child><object class=\"GtkRadioButton\" id=\"f"
  "ake_button\"><property name=\"label\" translatable=\"yes\">radiobutton<"
  "/property><property name=\"can_focus\">True</property><property name=\""
  "receives_default\">False</property><property name=\"active\">True</prop"
  "erty><property name=\"draw_indicator\">True</property></object><packing"
  "><property name=\"expand\">False</property><property name=\"fill\">Fals"
  "e</property><property name=\"position\">3</property></packing></child><"
  "child><object class=\"GtkButton\" id=\"cancel_button\"><property name=\""
  "label\" translatable=\"yes\">_Close</property><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">True</property><property name=\"image\">image5"
  "</property><property name=\"use_underline\">True</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">False</property><property name=\"position\">4</property></packing></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"pack_type\">end</prope"
  "rty><property name=\"position\">1</property></packing></child></object>"
  "</child></object></interface>"
};

static const unsigned minimal_display_dialog_ui_length = 9647u;

