/* automatically generated from profile-changed-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (profile_changed_dialog_ui)
#endif
#ifdef __GNUC__
static const char profile_changed_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char profile_changed_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><object class=\"GtkImage\" id=\"image2\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"icon_name\">window-close-symbolic</property><"
  "/object><object class=\"GtkDialog\" id=\"profile-changed-dialog\"><prop"
  "erty name=\"can_focus\">False</property><property name=\"title\" transl"
  "atable=\"yes\">Update Display Profile</property><property name=\"resiza"
  "ble\">False</property><property name=\"modal\">True</property><property"
  " name=\"window_position\">center</property><property name=\"icon_name\""
  ">dialog-question</property><property name=\"type_hint\">normal</propert"
  "y><child><placeholder/></child><child internal-child=\"vbox\"><object c"
  "lass=\"GtkBox\" id=\"dialog-vbox1\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"or"
  "ientation\">vertical</property><property name=\"spacing\">2</property><"
  "child internal-child=\"action_area\"><object class=\"GtkButtonBox\" id="
  "\"dialog-action_area1\"><property name=\"visible\">True</property><prop"
  "erty name=\"can_focus\">False</property><property name=\"layout_style\""
  ">end</property><child><object class=\"GtkButton\" id=\"button2\"><prope"
  "rty name=\"label\" translatable=\"yes\">_Close</property><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"can_default\">True</property><property name=\"has_def"
  "ault\">True</property><property name=\"receives_default\">True</propert"
  "y><property name=\"image\">image2</property><property name=\"use_underl"
  "ine\">True</property></object><packing><property name=\"expand\">False<"
  "/property><property name=\"fill\">False</property><property name=\"posi"
  "tion\">0</property></packing></child><child><object class=\"GtkButton\""
  " id=\"button-update\"><property name=\"label\" translatable=\"yes\">_Up"
  "date</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">True<"
  "/property><property name=\"use_underline\">True</property><style><class"
  " name=\"suggested-action\"/></style></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">False</property><prope"
  "rty name=\"position\">1</property><property name=\"non_homogeneous\">Tr"
  "ue</property></packing></child></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">True</property><property na"
  "me=\"pack_type\">end</property><property name=\"position\">0</property>"
  "</packing></child><child><object class=\"GtkBox\" id=\"hbox1\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"margin_right\">12</property><property name=\"m"
  "argin_top\">12</property><property name=\"spacing\">12</property><child"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"halign\">start</property><property name=\"valign\">start</property>"
  "<property name=\"margin_start\">10</property><property name=\"stock\">g"
  "tk-dialog-question</property><property name=\"icon_size\">6</property><"
  "/object><packing><property name=\"expand\">False</property><property na"
  "me=\"fill\">False</property><property name=\"position\">0</property></p"
  "acking></child><child><object class=\"GtkBox\" id=\"vbox1\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"orientation\">vertical</property><property name=\""
  "spacing\">12</property><child><object class=\"GtkLabel\" id=\"header\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"halign\">start</property><property nam"
  "e=\"label\" translatable=\"yes\">&lt;big&gt;&lt;b&gt;You have made chan"
  "ges to your previously active profile&lt;/b&gt;&lt;/big&gt;</property><"
  "property name=\"use_markup\">True</property></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">False</propert"
  "y><property name=\"position\">0</property></packing></child><child><obj"
  "ect class=\"GtkLabel\" id=\"label-confirmation\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"halign\">start</property><property name=\"margin_bottom\">24"
  "</property><property name=\"label\" translatable=\"yes\">If you don\'t "
  "update the profile your changes will be lost upon restarting your sessi"
  "on or disconnecting or connecting a display.</property><property name=\""
  "justify\">fill</property><property name=\"wrap\">True</property><proper"
  "ty name=\"max_width_chars\">50</property></object><packing><property na"
  "me=\"expand\">False</property><property name=\"fill\">False</property><"
  "property name=\"position\">1</property></packing></child></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">1</property></packing></child"
  "></object><packing><property name=\"expand\">True</property><property n"
  "ame=\"fill\">True</property><property name=\"position\">1</property></p"
  "acking></child></object></child><action-widgets><action-widget response"
  "=\"-7\">button2</action-widget><action-widget response=\"-5\">button-up"
  "date</action-widget></action-widgets></object></interface>"
};

static const unsigned profile_changed_dialog_ui_length = 5071u;

