/* automatically generated from confirmation-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (confirmation_dialog_ui)
#endif
#ifdef __GNUC__
static const char confirmation_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char confirmation_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><object class=\"GtkDialog\" id=\"dialog1\"><prop"
  "erty name=\"can_focus\">False</property><property name=\"title\" transl"
  "atable=\"yes\">Confirmation</property><property name=\"resizable\">Fals"
  "e</property><property name=\"modal\">True</property><property name=\"wi"
  "ndow_position\">center</property><property name=\"icon_name\">dialog-qu"
  "estion</property><property name=\"type_hint\">normal</property><child><"
  "placeholder/></child><child internal-child=\"vbox\"><object class=\"Gtk"
  "Box\" id=\"dialog-vbox1\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"orientation\""
  ">vertical</property><property name=\"spacing\">2</property><child inter"
  "nal-child=\"action_area\"><object class=\"GtkButtonBox\" id=\"dialog-ac"
  "tion_area1\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"layout_style\">end</proper"
  "ty><child><object class=\"GtkButton\" id=\"button2\"><property name=\"l"
  "abel\" translatable=\"yes\">Keep this configuration</property><property"
  " name=\"visible\">True</property><property name=\"can_focus\">True</pro"
  "perty><property name=\"can_default\">True</property><property name=\"ha"
  "s_default\">True</property><property name=\"receives_default\">True</pr"
  "operty></object><packing><property name=\"expand\">False</property><pro"
  "perty name=\"fill\">False</property><property name=\"position\">0</prop"
  "erty></packing></child><child><object class=\"GtkButton\" id=\"button1\""
  "><property name=\"label\" translatable=\"yes\">Restore the previous con"
  "figuration</property><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">True</property><property name=\"receives_default\""
  ">True</property></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">False</property><property name=\"position\""
  ">1</property></packing></child></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">True</property><property na"
  "me=\"pack_type\">end</property><property name=\"position\">0</property>"
  "</packing></child><child><object class=\"GtkBox\" id=\"hbox1\"><propert"
  "y name=\"visible\">True</property><property name=\"can_focus\">False</p"
  "roperty><property name=\"margin_right\">12</property><property name=\"m"
  "argin_top\">12</property><child><object class=\"GtkImage\" id=\"image1\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"halign\">start</property><property na"
  "me=\"valign\">start</property><property name=\"margin_right\">12</prope"
  "rty><property name=\"margin_start\">10</property><property name=\"stock"
  "\">gtk-dialog-question</property><property name=\"icon_size\">6</proper"
  "ty></object><packing><property name=\"expand\">False</property><propert"
  "y name=\"fill\">False</property><property name=\"position\">0</property"
  "></packing></child><child><object class=\"GtkBox\" id=\"vbox1\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"orientation\">vertical</property><property na"
  "me=\"spacing\">12</property><child><object class=\"GtkLabel\" id=\"labe"
  "l1\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"halign\">start</property><propert"
  "y name=\"label\" translatable=\"yes\">&lt;big&gt;&lt;b&gt;Would you lik"
  "e to keep this configuration?&lt;/b&gt;&lt;/big&gt;</property><property"
  " name=\"use_markup\">True</property></object><packing><property name=\""
  "expand\">False</property><property name=\"fill\">False</property><prope"
  "rty name=\"position\">0</property></packing></child><child><object clas"
  "s=\"GtkLabel\" id=\"label2\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"halign\">"
  "start</property><property name=\"margin_bottom\">24</property><property"
  " name=\"label\" translatable=\"yes\">The previous configuration will be"
  " restored in 10 seconds if you do not reply to this question.</property"
  "><property name=\"justify\">fill</property><property name=\"wrap\">True"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">False</property><property name=\"position\">1</"
  "property></packing></child></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object><packing><property na"
  "me=\"expand\">True</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">1</property></packing></child></object></child"
  "><action-widgets><action-widget response=\"2\">button2</action-widget><"
  "action-widget response=\"1\">button1</action-widget></action-widgets></"
  "object></interface>"
};

static const unsigned confirmation_dialog_ui_length = 4562u;

