/* automatically generated from display-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (display_dialog_ui)
#endif
#ifdef __GNUC__
static const char display_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char display_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.13\"/"
  "><object class=\"GtkAdjustment\" id=\"adjustment1\"><property name=\"lo"
  "wer\">0.10000000000000001</property><property name=\"upper\">10</proper"
  "ty><property name=\"step_increment\">0.10000000000000001</property><pro"
  "perty name=\"page_increment\">1</property></object><object class=\"GtkI"
  "mage\" id=\"image1\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"icon_name\">edit-"
  "delete-symbolic</property></object><object class=\"GtkImage\" id=\"imag"
  "e2\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"icon_name\">document-save-symboli"
  "c</property></object><object class=\"GtkImage\" id=\"image3\"><property"
  " name=\"visible\">True</property><property name=\"can_focus\">False</pr"
  "operty><property name=\"icon_name\">window-close-symbolic</property></o"
  "bject><object class=\"GtkImage\" id=\"image4\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"icon_name\">object-select-symbolic</property></object><object "
  "class=\"GtkImage\" id=\"image5\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"icon_"
  "name\">document-new-symbolic</property></object><object class=\"GtkImag"
  "e\" id=\"image6\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">help-bro"
  "wser</property></object><object class=\"GtkImage\" id=\"image7\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"icon_name\">object-select-symbolic</property"
  "></object><object class=\"GtkListStore\" id=\"liststore1\"><columns><co"
  "lumn type=\"gchararray\"/><column type=\"gdouble\"/></columns><data><ro"
  "w><col id=\"0\">1x</col><col id=\"1\">1</col></row><row><col id=\"0\" t"
  "ranslatable=\"yes\">1.5x</col><col id=\"1\">1.5</col></row><row><col id"
  "=\"0\" translatable=\"yes\">2x</col><col id=\"1\">2</col></row><row><co"
  "l id=\"0\" translatable=\"yes\">Custom:</col><col id=\"1\">-1</col></ro"
  "w></data></object><object class=\"GtkPopover\" id=\"primary-info\"><pro"
  "perty name=\"can_focus\">False</property><property name=\"position\">bo"
  "ttom</property><child><object class=\"GtkGrid\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"margin_left\">12</property><property name=\"margin_right\">12"
  "</property><property name=\"margin_top\">12</property><property name=\""
  "margin_bottom\">12</property><child><object class=\"GtkImage\" id=\"pan"
  "el-ok\"><property name=\"can_focus\">False</property><property name=\"m"
  "argin_left\">18</property><property name=\"icon_name\">emblem-ok-symbol"
  "ic</property><style><class name=\"success\"/></style></object><packing>"
  "<property name=\"left_attach\">0</property><property name=\"top_attach\""
  ">1</property></packing></child><child><object class=\"GtkImage\" id=\"d"
  "esktop-ok\"><property name=\"can_focus\">False</property><property name"
  "=\"margin_left\">18</property><property name=\"icon_name\">emblem-ok-sy"
  "mbolic</property></object><packing><property name=\"left_attach\">0</pr"
  "operty><property name=\"top_attach\">2</property></packing></child><chi"
  "ld><object class=\"GtkImage\" id=\"notifications-ok\"><property name=\""
  "can_focus\">False</property><property name=\"margin_left\">18</property"
  "><property name=\"icon_name\">emblem-ok-symbolic</property></object><pa"
  "cking><property name=\"left_attach\">0</property><property name=\"top_a"
  "ttach\">3</property></packing></child><child><object class=\"GtkLabel\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"margin_bottom\">12</property><propert"
  "y name=\"label\" translatable=\"yes\">The primary display is currently "
  "configured to show:</property><property name=\"xalign\">0</property></o"
  "bject><packing><property name=\"left_attach\">0</property><property nam"
  "e=\"top_attach\">0</property><property name=\"width\">3</property></pac"
  "king></child><child><object class=\"GtkLabel\" id=\"panel-label\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"hexpand\">True</property><property name=\"l"
  "abel\" translatable=\"yes\">Xfce Panel</property><property name=\"xalig"
  "n\">0</property></object><packing><property name=\"left_attach\">1</pro"
  "perty><property name=\"top_attach\">1</property></packing></child><chil"
  "d><object class=\"GtkLabel\" id=\"desktop-label\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">False</property><prop"
  "erty name=\"hexpand\">True</property><property name=\"label\" translata"
  "ble=\"yes\">Desktop icons</property><property name=\"xalign\">0</proper"
  "ty></object><packing><property name=\"left_attach\">1</property><proper"
  "ty name=\"top_attach\">2</property></packing></child><child><object cla"
  "ss=\"GtkLabel\" id=\"notifications-label\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"hexpand\">True</property><property name=\"label\" translatable=\"y"
  "es\">Notifications</property><property name=\"xalign\">0</property></ob"
  "ject><packing><property name=\"left_attach\">1</property><property name"
  "=\"top_attach\">3</property></packing></child><child><object class=\"Gt"
  "kButton\" id=\"panel-configure\"><property name=\"label\" translatable="
  "\"yes\">Configure...</property><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">True</property><property name=\"receives"
  "_default\">True</property><style><class name=\"flat\"/></style></object"
  "><packing><property name=\"left_attach\">2</property><property name=\"t"
  "op_attach\">1</property></packing></child><child><object class=\"GtkBut"
  "ton\" id=\"desktop-configure\"><property name=\"label\" translatable=\""
  "yes\">Configure...</property><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">True</property><property name=\"receives_d"
  "efault\">True</property><style><class name=\"flat\"/></style></object><"
  "packing><property name=\"left_attach\">2</property><property name=\"top"
  "_attach\">2</property></packing></child><child><object class=\"GtkButto"
  "n\" id=\"notifications-configure\"><property name=\"label\" translatabl"
  "e=\"yes\">Configure...</property><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">True</property><property name=\"receiv"
  "es_default\">True</property><style><class name=\"flat\"/></style></obje"
  "ct><packing><property name=\"left_attach\">2</property><property name=\""
  "top_attach\">3</property></packing></child></object></child></object><o"
  "bject class=\"XfceTitledDialog\" id=\"display-dialog\"><property name=\""
  "can_focus\">False</property><property name=\"title\" translatable=\"yes"
  "\">Display</property><property name=\"window_position\">center-on-paren"
  "t</property><property name=\"default_width\">400</property><property na"
  "me=\"default_height\">400</property><property name=\"icon_name\">org.xf"
  "ce.settings.display</property><property name=\"type_hint\">dialog</prop"
  "erty><child internal-child=\"vbox\"><object class=\"GtkBox\" id=\"dialo"
  "g-vbox1\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"orientation\">vertical</prop"
  "erty><property name=\"spacing\">2</property><child internal-child=\"act"
  "ion_area\"><object class=\"GtkButtonBox\" id=\"dialog-action_area1\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"layout_style\">end</property><child><obj"
  "ect class=\"GtkButton\" id=\"button-help\"><property name=\"label\" tra"
  "nslatable=\"yes\">_Help</property><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">True</property><property name=\"recei"
  "ves_default\">True</property><property name=\"image\">image6</property>"
  "<property name=\"use_underline\">True</property></object><packing><prop"
  "erty name=\"expand\">False</property><property name=\"fill\">False</pro"
  "perty><property name=\"position\">0</property><property name=\"secondar"
  "y\">True</property></packing></child><child><object class=\"GtkButton\""
  " id=\"button-close\"><property name=\"label\" translatable=\"yes\">_Clo"
  "se</property><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">True</pr"
  "operty><property name=\"image\">image3</property><property name=\"use_u"
  "nderline\">True</property></object><packing><property name=\"expand\">F"
  "alse</property><property name=\"fill\">False</property><property name=\""
  "position\">1</property></packing></child></object><packing><property na"
  "me=\"expand\">False</property><property name=\"fill\">True</property><p"
  "roperty name=\"pack_type\">end</property><property name=\"position\">1<"
  "/property></packing></child><child><object class=\"GtkBox\" id=\"plug-c"
  "hild\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"border_width\">6</property><pro"
  "perty name=\"orientation\">vertical</property><property name=\"spacing\""
  ">6</property><child><object class=\"GtkNotebook\"><property name=\"visi"
  "ble\">True</property><property name=\"can_focus\">True</property><prope"
  "rty name=\"hexpand\">True</property><property name=\"vexpand\">True</pr"
  "operty><child><object class=\"GtkBox\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "margin_left\">12</property><property name=\"margin_right\">12</property"
  "><property name=\"margin_top\">12</property><property name=\"margin_bot"
  "tom\">12</property><property name=\"spacing\">6</property><child><objec"
  "t class=\"GtkBox\" id=\"display-settings\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"orientation\">vertical</property><property name=\"spacing\">9</pro"
  "perty><child><object class=\"GtkFrame\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"label_xalign\">0</property><property name=\"label_yalign\">0</propert"
  "y><property name=\"shadow_type\">in</property><child><object class=\"Gt"
  "kAlignment\" id=\"randr-dnd\"><property name=\"width_request\">350</pro"
  "perty><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><child><placeholder/></child></object></child><ch"
  "ild type=\"label_item\"><placeholder/></child></object><packing><proper"
  "ty name=\"expand\">True</property><property name=\"fill\">True</propert"
  "y><property name=\"position\">0</property></packing></child><child><obj"
  "ect class=\"GtkCheckButton\" id=\"mirror-displays\"><property name=\"la"
  "bel\" translatable=\"yes\">_Mirror displays</property><property name=\""
  "visible\">True</property><property name=\"can_focus\">True</property><p"
  "roperty name=\"receives_default\">False</property><property name=\"use_"
  "underline\">True</property><property name=\"draw_indicator\">True</prop"
  "erty></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">1</propert"
  "y></packing></child></object><packing><property name=\"expand\">True</p"
  "roperty><property name=\"fill\">True</property><property name=\"positio"
  "n\">0</property></packing></child><child><object class=\"GtkGrid\" id=\""
  "table1\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property><property name=\"row_spacing\">3</property><pr"
  "operty name=\"column_spacing\">3</property><child><object class=\"GtkBo"
  "x\"><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">False</property><property name=\"margin_bottom\">3</property><prope"
  "rty name=\"spacing\">12</property><child><object class=\"GtkComboBox\" "
  "id=\"randr-outputs\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"hexpand\">True</p"
  "roperty></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">True</property><property name=\"position\">0</prop"
  "erty></packing></child><child><object class=\"GtkSwitch\" id=\"output-o"
  "n\"><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"halign\">end</property><property na"
  "me=\"valign\">center</property></object><packing><property name=\"expan"
  "d\">False</property><property name=\"fill\">True</property><property na"
  "me=\"position\">1</property></packing></child></object><packing><proper"
  "ty name=\"left_attach\">0</property><property name=\"top_attach\">0</pr"
  "operty><property name=\"width\">4</property></packing></child><child><o"
  "bject class=\"GtkMenuButton\" id=\"primary-info-button\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"receives_default\">True</property><property name=\"re"
  "lief\">none</property><property name=\"popover\">primary-info</property"
  "><child><placeholder/></child></object><packing><property name=\"left_a"
  "ttach\">3</property><property name=\"top_attach\">1</property></packing"
  "></child><child><object class=\"GtkSwitch\" id=\"primary\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">True</proper"
  "ty><property name=\"halign\">end</property><property name=\"valign\">ce"
  "nter</property><property name=\"margin_left\">9</property><property nam"
  "e=\"margin_bottom\">3</property></object><packing><property name=\"left"
  "_attach\">2</property><property name=\"top_attach\">1</property></packi"
  "ng></child><child><object class=\"GtkLabel\" id=\"label-primary\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"halign\">start</property><property name=\"m"
  "argin_bottom\">3</property><property name=\"label\" translatable=\"yes\""
  ">Primary Display:</property><property name=\"use_underline\">True</prop"
  "erty></object><packing><property name=\"left_attach\">1</property><prop"
  "erty name=\"top_attach\">1</property></packing></child><child><object c"
  "lass=\"GtkComboBox\" id=\"randr-resolution\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"margin_left\">9</property><property name=\"margin_bottom\">3</pr"
  "operty></object><packing><property name=\"left_attach\">2</property><pr"
  "operty name=\"top_attach\">2</property></packing></child><child><object"
  " class=\"GtkLabel\" id=\"label-resolution\"><property name=\"visible\">"
  "True</property><property name=\"can_focus\">False</property><property n"
  "ame=\"halign\">start</property><property name=\"margin_bottom\">3</prop"
  "erty><property name=\"label\" translatable=\"yes\">R_esolution:</proper"
  "ty><property name=\"use_underline\">True</property></object><packing><p"
  "roperty name=\"left_attach\">1</property><property name=\"top_attach\">"
  "2</property></packing></child><child><object class=\"GtkComboBox\" id=\""
  "randr-refresh-rate\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"margin_left\">9</"
  "property><property name=\"margin_bottom\">3</property></object><packing"
  "><property name=\"left_attach\">2</property><property name=\"top_attach"
  "\">5</property></packing></child><child><object class=\"GtkLabel\" id=\""
  "label-refresh-rate\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><property name=\"halign\">start</p"
  "roperty><property name=\"margin_bottom\">3</property><property name=\"l"
  "abel\" translatable=\"yes\">Refresh _rate:</property><property name=\"u"
  "se_underline\">True</property></object><packing><property name=\"left_a"
  "ttach\">1</property><property name=\"top_attach\">5</property></packing"
  "></child><child><object class=\"GtkComboBox\" id=\"randr-rotation\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"margin_left\">9</property><property name="
  "\"margin_bottom\">3</property></object><packing><property name=\"left_a"
  "ttach\">2</property><property name=\"top_attach\">6</property></packing"
  "></child><child><object class=\"GtkLabel\" id=\"label-rotation\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"halign\">start</property><property name=\"ma"
  "rgin_bottom\">3</property><property name=\"label\" translatable=\"yes\""
  ">Ro_tation:</property><property name=\"use_underline\">True</property><"
  "/object><packing><property name=\"left_attach\">1</property><property n"
  "ame=\"top_attach\">6</property></packing></child><child><object class=\""
  "GtkComboBox\" id=\"randr-reflection\"><property name=\"can_focus\">Fals"
  "e</property><property name=\"margin_left\">9</property><property name=\""
  "margin_bottom\">3</property></object><packing><property name=\"left_att"
  "ach\">2</property><property name=\"top_attach\">7</property></packing><"
  "/child><child><object class=\"GtkLabel\" id=\"label-reflection\"><prope"
  "rty name=\"can_focus\">False</property><property name=\"halign\">start<"
  "/property><property name=\"margin_bottom\">3</property><property name=\""
  "label\" translatable=\"yes\">Ref_lection:</property><property name=\"us"
  "e_underline\">True</property></object><packing><property name=\"left_at"
  "tach\">1</property><property name=\"top_attach\">7</property></packing>"
  "</child><child><object class=\"GtkImage\" id=\"primary-indicator\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">Fals"
  "e</property><property name=\"valign\">center</property><property name=\""
  "margin_left\">6</property><property name=\"pixel_size\">16</property><p"
  "roperty name=\"icon_name\">help-about-symbolic</property></object><pack"
  "ing><property name=\"left_attach\">0</property><property name=\"top_att"
  "ach\">1</property></packing></child><child><object class=\"GtkImage\" i"
  "d=\"dummy-icon\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"margin_left\">6</prop"
  "erty><property name=\"pixel_size\">16</property></object><packing><prop"
  "erty name=\"left_attach\">0</property><property name=\"top_attach\">2</"
  "property></packing></child><child><object class=\"GtkBox\" id=\"hbox1\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><child><placeholder/></child><child><object class=\"Gt"
  "kButton\" id=\"apply\"><property name=\"label\" translatable=\"yes\">A_"
  "pply</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">True<"
  "/property><property name=\"margin_top\">6</property><property name=\"im"
  "age\">image4</property><property name=\"use_underline\">True</property>"
  "</object><packing><property name=\"expand\">False</property><property n"
  "ame=\"fill\">True</property><property name=\"pack_type\">end</property>"
  "<property name=\"position\">1</property></packing></child></object><pac"
  "king><property name=\"left_attach\">0</property><property name=\"top_at"
  "tach\">8</property><property name=\"width\">3</property></packing></chi"
  "ld><child><object class=\"GtkLabel\" id=\"label-scale\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"halign\">start</property><property name=\"label\" tra"
  "nslatable=\"yes\">_Scale:</property><property name=\"use_underline\">Tr"
  "ue</property></object><packing><property name=\"left_attach\">1</proper"
  "ty><property name=\"top_attach\">3</property></packing></child><child><"
  "object class=\"GtkRevealer\" id=\"revealer-scale\"><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">False</property><pro"
  "perty name=\"reveal_child\">True</property><child><object class=\"GtkGr"
  "id\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"margin_left\">9</property><proper"
  "ty name=\"margin_top\">3</property><property name=\"margin_bottom\">3</"
  "property><property name=\"row_spacing\">3</property><child><object clas"
  "s=\"GtkLabel\" id=\"label-scale-x\"><property name=\"visible\">True</pr"
  "operty><property name=\"can_focus\">False</property><property name=\"ha"
  "lign\">end</property><property name=\"label\" translatable=\"yes\">X:</"
  "property><property name=\"xalign\">1</property></object><packing><prope"
  "rty name=\"left_attach\">0</property><property name=\"top_attach\">0</p"
  "roperty></packing></child><child><object class=\"GtkLabel\" id=\"label-"
  "scale-y\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">False</property><property name=\"halign\">end</property><prop"
  "erty name=\"label\" translatable=\"yes\">Y:</property><property name=\""
  "xalign\">1</property></object><packing><property name=\"left_attach\">0"
  "</property><property name=\"top_attach\">1</property></packing></child>"
  "<child><object class=\"GtkSpinButton\" id=\"spin-scale-x\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">True</proper"
  "ty><property name=\"halign\">end</property><property name=\"hexpand\">T"
  "rue</property><property name=\"adjustment\">adjustment1</property><prop"
  "erty name=\"digits\">1</property></object><packing><property name=\"lef"
  "t_attach\">1</property><property name=\"top_attach\">0</property></pack"
  "ing></child><child><object class=\"GtkSpinButton\" id=\"spin-scale-y\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "True</property><property name=\"halign\">end</property><property name=\""
  "hexpand\">True</property><property name=\"adjustment\">adjustment1</pro"
  "perty><property name=\"digits\">1</property></object><packing><property"
  " name=\"left_attach\">1</property><property name=\"top_attach\">1</prop"
  "erty></packing></child></object></child></object><packing><property nam"
  "e=\"left_attach\">2</property><property name=\"top_attach\">4</property"
  "></packing></child><child><object class=\"GtkComboBox\" id=\"randr-scal"
  "e\"><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">False</property><property name=\"margin_left\">9</property><propert"
  "y name=\"model\">liststore1</property><child><object class=\"GtkCellRen"
  "dererText\" id=\"cellrenderertext1\"/><attributes><attribute name=\"tex"
  "t\">0</attribute></attributes></child></object><packing><property name="
  "\"left_attach\">2</property><property name=\"top_attach\">3</property><"
  "/packing></child><child><placeholder/></child><child><placeholder/></ch"
  "ild><child><placeholder/></child><child><placeholder/></child><child><p"
  "laceholder/></child><child><placeholder/></child><child><placeholder/><"
  "/child><child><placeholder/></child><child><placeholder/></child><child"
  "><placeholder/></child><child><placeholder/></child><child><placeholder"
  "/></child><child><placeholder/></child></object><packing><property name"
  "=\"expand\">False</property><property name=\"fill\">True</property><pro"
  "perty name=\"pack_type\">end</property><property name=\"position\">1</p"
  "roperty></packing></child></object></child><child type=\"tab\"><object "
  "class=\"GtkLabel\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"label\" translatabl"
  "e=\"yes\">_General</property><property name=\"use_underline\">True</pro"
  "perty></object><packing><property name=\"tab_fill\">False</property></p"
  "acking></child><child><object class=\"GtkGrid\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"border_width\">12</property><property name=\"row_spacing\">6<"
  "/property><property name=\"column_spacing\">12</property><child><object"
  " class=\"GtkLabel\" id=\"label-profile\"><property name=\"visible\">Tru"
  "e</property><property name=\"can_focus\">False</property><property name"
  "=\"halign\">start</property><property name=\"label\" translatable=\"yes"
  "\">&lt;b&gt;Profiles&lt;/b&gt;</property><property name=\"use_markup\">"
  "True</property><property name=\"use_underline\">True</property></object"
  "><packing><property name=\"left_attach\">0</property><property name=\"t"
  "op_attach\">0</property><property name=\"width\">2</property></packing>"
  "</child><child><object class=\"GtkLabel\" id=\"label-profile1\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"halign\">start</property><property name=\"mar"
  "gin_top\">12</property><property name=\"label\" translatable=\"yes\">&l"
  "t;b&gt;Connecting Displays&lt;/b&gt;</property><property name=\"use_mar"
  "kup\">True</property><property name=\"use_underline\">True</property></"
  "object><packing><property name=\"left_attach\">0</property><property na"
  "me=\"top_attach\">2</property><property name=\"width\">2</property></pa"
  "cking></child><child><object class=\"GtkBox\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"margin_left\">12</property><property name=\"hexpand\">True</prop"
  "erty><property name=\"orientation\">vertical</property><child><object c"
  "lass=\"GtkScrolledWindow\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">True</property><property name=\"shadow_type\""
  ">in</property><child><object class=\"GtkTreeView\" id=\"randr-profile\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">True</property><property name=\"hexpand\">True</property><property nam"
  "e=\"vexpand\">True</property><property name=\"border_width\">1</propert"
  "y><child internal-child=\"selection\"><object class=\"GtkTreeSelection\""
  "/></child></object></child></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkBox\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><child><object class=\"GtkButton\" id=\"button-profile"
  "-delete\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">True</property><property name=\"receives_default\">True</prop"
  "erty><property name=\"tooltip_text\" translatable=\"yes\">Delete the cu"
  "rrently selected display profile.</property><property name=\"image\">im"
  "age1</property><property name=\"always_show_image\">True</property></ob"
  "ject><packing><property name=\"expand\">False</property><property name="
  "\"fill\">True</property><property name=\"pack_type\">end</property><pro"
  "perty name=\"position\">-1</property></packing></child><child><object c"
  "lass=\"GtkButton\" id=\"button-profile-apply\"><property name=\"label\""
  " translatable=\"yes\">Apply</property><property name=\"visible\">True</"
  "property><property name=\"can_focus\">True</property><property name=\"r"
  "eceives_default\">True</property><property name=\"tooltip_text\" transl"
  "atable=\"yes\">Apply the currently selected display profile.</property>"
  "<property name=\"image\">image7</property><property name=\"always_show_"
  "image\">True</property></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pac"
  "k_type\">end</property><property name=\"position\">0</property></packin"
  "g></child><child><object class=\"GtkButton\" id=\"button-profile-create"
  "\"><property name=\"visible\">True</property><property name=\"can_focus"
  "\">True</property><property name=\"receives_default\">True</property><p"
  "roperty name=\"tooltip_text\" translatable=\"yes\">Create a new display"
  " profile.</property><property name=\"image\">image5</property><property"
  " name=\"always_show_image\">True</property></object><packing><property "
  "name=\"expand\">False</property><property name=\"fill\">True</property>"
  "<property name=\"pack_type\">end</property><property name=\"position\">"
  "1</property></packing></child><child><object class=\"GtkButton\" id=\"b"
  "utton-profile-save\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">True</property><property name=\"receives_default\""
  ">True</property><property name=\"tooltip_text\" translatable=\"yes\">Up"
  "date an existing profile.</property><property name=\"image\">image2</pr"
  "operty><property name=\"always_show_image\">True</property></object><pa"
  "cking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"pack_type\">end</property><property na"
  "me=\"position\">2</property></packing></child><style><class name=\"inli"
  "ne-toolbar\"/></style></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">1</property></packing></child></object><packing><property name=\""
  "left_attach\">0</property><property name=\"top_attach\">1</property><pr"
  "operty name=\"width\">2</property></packing></child><child><object clas"
  "s=\"GtkLabel\" id=\"auto-enable-profiles-label\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">False</property><prope"
  "rty name=\"margin_left\">12</property><property name=\"label\" translat"
  "able=\"yes\">Automatically enable profiles when new display is connecte"
  "d</property><property name=\"xalign\">0</property></object><packing><pr"
  "operty name=\"left_attach\">0</property><property name=\"top_attach\">4"
  "</property></packing></child><child><object class=\"GtkSwitch\" id=\"au"
  "to-enable-profiles\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">True</property><property name=\"halign\">end</prop"
  "erty><property name=\"valign\">center</property></object><packing><prop"
  "erty name=\"left_attach\">1</property><property name=\"top_attach\">4</"
  "property></packing></child><child><object class=\"GtkLabel\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"margin_left\">12</property><property name=\"labe"
  "l\" translatable=\"yes\">Configure new displays when connected</propert"
  "y><property name=\"xalign\">0</property></object><packing><property nam"
  "e=\"left_attach\">0</property><property name=\"top_attach\">3</property"
  "></packing></child><child><object class=\"GtkSwitch\" id=\"minimal-auto"
  "show\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">True</property><property name=\"halign\">end</property><property"
  " name=\"valign\">center</property></object><packing><property name=\"le"
  "ft_attach\">1</property><property name=\"top_attach\">3</property></pac"
  "king></child><child><object class=\"GtkLabel\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"margin_left\">12</property><property name=\"label\" translatab"
  "le=\"yes\">Show popup windows to identify displays</property><property "
  "name=\"xalign\">0</property></object><packing><property name=\"left_att"
  "ach\">0</property><property name=\"top_attach\">6</property></packing><"
  "/child><child><object class=\"GtkSwitch\" id=\"identify-displays\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"halign\">end</property><property name=\"val"
  "ign\">center</property></object><packing><property name=\"left_attach\""
  ">1</property><property name=\"top_attach\">6</property></packing></chil"
  "d><child><object class=\"GtkLabel\" id=\"label-profile2\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"halign\">start</property><property name=\"margin_to"
  "p\">12</property><property name=\"label\" translatable=\"yes\">&lt;b&gt"
  ";Identifying Displays&lt;/b&gt;</property><property name=\"use_markup\""
  ">True</property><property name=\"use_underline\">True</property></objec"
  "t><packing><property name=\"left_attach\">0</property><property name=\""
  "top_attach\">5</property><property name=\"width\">2</property></packing"
  "></child></object><packing><property name=\"position\">1</property></pa"
  "cking></child><child type=\"tab\"><object class=\"GtkLabel\"><property "
  "name=\"visible\">True</property><property name=\"can_focus\">False</pro"
  "perty><property name=\"label\" translatable=\"yes\">_Advanced</property"
  "><property name=\"use_underline\">True</property></object><packing><pro"
  "perty name=\"position\">1</property><property name=\"tab_fill\">False</"
  "property></packing></child><child><placeholder/></child><child type=\"t"
  "ab\"><placeholder/></child></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">True</property><property name=\""
  "position\">1</property></packing></child></object><packing><property na"
  "me=\"expand\">True</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">2</property></packing></child></object></child"
  "><action-widgets><action-widget response=\"-11\">button-help</action-wi"
  "dget><action-widget response=\"-7\">button-close</action-widget></actio"
  "n-widgets></object><object class=\"GtkPopover\" id=\"popover-create-pro"
  "file\"><property name=\"can_focus\">False</property><property name=\"re"
  "lative_to\">button-profile-create</property><child><object class=\"GtkB"
  "ox\"><property name=\"visible\">True</property><property name=\"can_foc"
  "us\">False</property><property name=\"orientation\">vertical</property>"
  "<child><object class=\"GtkGrid\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"margi"
  "n_left\">12</property><property name=\"margin_right\">12</property><pro"
  "perty name=\"margin_top\">12</property><property name=\"margin_bottom\""
  ">24</property><property name=\"row_spacing\">6</property><property name"
  "=\"column_spacing\">6</property><child><object class=\"GtkLabel\"><prop"
  "erty name=\"visible\">True</property><property name=\"can_focus\">False"
  "</property><property name=\"label\" translatable=\"yes\">&lt;b&gt;Profi"
  "le Name&lt;/b&gt;</property><property name=\"use_markup\">True</propert"
  "y><property name=\"xalign\">0</property></object><packing><property nam"
  "e=\"left_attach\">0</property><property name=\"top_attach\">0</property"
  "></packing></child><child><object class=\"GtkEntry\" id=\"entry-profile"
  "-create\"><property name=\"visible\">True</property><property name=\"ca"
  "n_focus\">True</property><property name=\"hexpand\">True</property><pro"
  "perty name=\"activates_default\">True</property></object><packing><prop"
  "erty name=\"left_attach\">0</property><property name=\"top_attach\">1</"
  "property></packing></child><child><object class=\"GtkButton\" id=\"butt"
  "on-profile-create-cb\"><property name=\"label\" translatable=\"yes\">Cr"
  "eate</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"can_default\">True</prop"
  "erty><property name=\"has_default\">True</property><property name=\"rec"
  "eives_default\">True</property><style><class name=\"suggested-action\"/"
  "></style></object><packing><property name=\"left_attach\">1</property><"
  "property name=\"top_attach\">1</property></packing></child><child><obje"
  "ct class=\"GtkBox\" id=\"profile-exists\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"spacing\">6</property><child><object class=\"GtkImage\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><property name=\"icon_name\">dialog-error-symbolic</property></obj"
  "ect><packing><property name=\"expand\">True</property><property name=\""
  "fill\">True</property><property name=\"position\">0</property></packing"
  "></child><child><object class=\"GtkLabel\"><property name=\"can_focus\""
  ">False</property><property name=\"label\" translatable=\"yes\">A profil"
  "e of this name already exists.</property></object><packing><property na"
  "me=\"expand\">True</property><property name=\"fill\">True</property><pr"
  "operty name=\"position\">1</property></packing></child></object><packin"
  "g><property name=\"left_attach\">0</property><property name=\"top_attac"
  "h\">2</property><property name=\"width\">2</property></packing></child>"
  "<child><placeholder/></child></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">0</property></packing></child></object></child></object></"
  "interface>"
};

static const unsigned display_dialog_ui_length = 33780u;

