/* automatically generated from keyboard-dialog.glade */
#ifdef __SUNPRO_C
#pragma align 4 (keyboard_dialog_ui)
#endif
#ifdef __GNUC__
static const char keyboard_dialog_ui[] __attribute__ ((__aligned__ (4))) =
#else
static const char keyboard_dialog_ui[] =
#endif
{
  "<?xml version=\"1.0\" encoding=\"UTF-8\"?><interface><requires lib=\"gt"
  "k+\" version=\"3.20\"/><requires lib=\"libxfce4ui-2\" version=\"4.13\"/"
  "><object class=\"GtkImage\" id=\"image1\"><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">False</property><property nam"
  "e=\"icon_name\">document-revert-symbolic</property></object><object cla"
  "ss=\"GtkImage\" id=\"image10\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"icon_na"
  "me\">document-edit-symbolic</property></object><object class=\"GtkImage"
  "\" id=\"image11\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><property name=\"icon_name\">list-rem"
  "ove-symbolic</property></object><object class=\"GtkImage\" id=\"image2\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><property name=\"icon_name\">window-close-symbolic</pr"
  "operty></object><object class=\"GtkImage\" id=\"image5\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">False</propert"
  "y><property name=\"icon_name\">help-browser</property></object><object "
  "class=\"GtkImage\" id=\"image6\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"icon_"
  "name\">list-add-symbolic</property></object><object class=\"GtkImage\" "
  "id=\"image7\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"icon_name\">list-remove-"
  "symbolic</property></object><object class=\"GtkImage\" id=\"image8\"><p"
  "roperty name=\"visible\">True</property><property name=\"can_focus\">Fa"
  "lse</property><property name=\"icon_name\">document-edit-symbolic</prop"
  "erty></object><object class=\"GtkImage\" id=\"image9\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"icon_name\">list-add-symbolic</property></object><objec"
  "t class=\"XfceTitledDialog\" id=\"keyboard-layout-selection-dialog\"><p"
  "roperty name=\"can_focus\">False</property><property name=\"title\" tra"
  "nslatable=\"yes\">Keyboard layout selection</property><property name=\""
  "window_position\">center-on-parent</property><property name=\"default_h"
  "eight\">300</property><property name=\"icon_name\">org.xfce.settings.ke"
  "yboard</property><property name=\"type_hint\">dialog</property><child i"
  "nternal-child=\"vbox\"><object class=\"GtkBox\" id=\"dialog-vbox2\"><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Fal"
  "se</property><property name=\"orientation\">vertical</property><propert"
  "y name=\"spacing\">2</property><child internal-child=\"action_area\"><o"
  "bject class=\"GtkButtonBox\" id=\"dialog-action_area2\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">False</property"
  "><property name=\"layout_style\">end</property><child><object class=\"G"
  "tkButton\" id=\"layout_selection_cancel_button\"><property name=\"label"
  "\" translatable=\"yes\">_Cancel</property><property name=\"visible\">Tr"
  "ue</property><property name=\"can_focus\">True</property><property name"
  "=\"receives_default\">True</property><property name=\"use_underline\">T"
  "rue</property></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">False</property><property name=\"position\">"
  "0</property></packing></child><child><object class=\"GtkButton\" id=\"l"
  "ayout_selection_ok_button\"><property name=\"label\" translatable=\"yes"
  "\">_OK</property><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">True</property><property name=\"receives_default\">Tru"
  "e</property><property name=\"use_underline\">True</property></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">False</property><property name=\"position\">1</property></packing></ch"
  "ild></object><packing><property name=\"expand\">False</property><proper"
  "ty name=\"fill\">True</property><property name=\"pack_type\">end</prope"
  "rty><property name=\"position\">0</property></packing></child><child><o"
  "bject class=\"GtkScrolledWindow\" id=\"scrolledwindow3\"><property name"
  "=\"visible\">True</property><property name=\"can_focus\">True</property"
  "><property name=\"border_width\">6</property><property name=\"shadow_ty"
  "pe\">in</property><child><object class=\"GtkTreeView\" id=\"layout_sele"
  "ction_view\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"headers_visible\">False</pr"
  "operty><property name=\"search_column\">0</property><child internal-chi"
  "ld=\"selection\"><object class=\"GtkTreeSelection\" id=\"treeview-selec"
  "tion1\"/></child></object></child></object><packing><property name=\"ex"
  "pand\">True</property><property name=\"fill\">True</property><property "
  "name=\"position\">1</property></packing></child></object></child><actio"
  "n-widgets><action-widget response=\"-6\">layout_selection_cancel_button"
  "</action-widget><action-widget response=\"-5\">layout_selection_ok_butt"
  "on</action-widget></action-widgets></object><object class=\"GtkAdjustme"
  "nt\" id=\"net_cursor_blink_time\"><property name=\"lower\">100</propert"
  "y><property name=\"upper\">2000</property><property name=\"value\">1000"
  "</property><property name=\"step_increment\">1</property><property name"
  "=\"page_increment\">10</property></object><object class=\"GtkSizeGroup\""
  " id=\"sizegroup1\"/><object class=\"GtkAdjustment\" id=\"xkb_key_repeat"
  "_delay\"><property name=\"lower\">10</property><property name=\"upper\""
  ">1000</property><property name=\"value\">500</property><property name=\""
  "step_increment\">1</property><property name=\"page_increment\">10</prop"
  "erty></object><object class=\"GtkAdjustment\" id=\"xkb_key_repeat_rate\""
  "><property name=\"lower\">1</property><property name=\"upper\">250</pro"
  "perty><property name=\"value\">20</property><property name=\"step_incre"
  "ment\">1</property><property name=\"page_increment\">10</property></obj"
  "ect><object class=\"XfceTitledDialog\" id=\"keyboard-settings-dialog\">"
  "<property name=\"can_focus\">False</property><property name=\"title\" t"
  "ranslatable=\"yes\">Keyboard</property><property name=\"window_position"
  "\">center-on-parent</property><property name=\"default_width\">400</pro"
  "perty><property name=\"default_height\">600</property><property name=\""
  "icon_name\">preferences-desktop-keyboard</property><property name=\"typ"
  "e_hint\">dialog</property><child internal-child=\"vbox\"><object class="
  "\"GtkBox\" id=\"dialog-vbox1\"><property name=\"visible\">True</propert"
  "y><property name=\"can_focus\">False</property><property name=\"orienta"
  "tion\">vertical</property><property name=\"spacing\">2</property><child"
  " internal-child=\"action_area\"><object class=\"GtkButtonBox\" id=\"dia"
  "log-action_area1\"><property name=\"visible\">True</property><property "
  "name=\"can_focus\">False</property><property name=\"layout_style\">end<"
  "/property><child><object class=\"GtkButton\" id=\"button2\"><property n"
  "ame=\"label\" translatable=\"yes\">_Close</property><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">True</property><pro"
  "perty name=\"receives_default\">True</property><property name=\"image\""
  ">image2</property><property name=\"use_underline\">True</property></obj"
  "ect><packing><property name=\"expand\">False</property><property name=\""
  "fill\">False</property><property name=\"position\">0</property></packin"
  "g></child><child><object class=\"GtkButton\" id=\"button1\"><property n"
  "ame=\"label\" translatable=\"yes\">_Help</property><property name=\"vis"
  "ible\">True</property><property name=\"can_focus\">True</property><prop"
  "erty name=\"receives_default\">True</property><property name=\"image\">"
  "image5</property><property name=\"use_underline\">True</property></obje"
  "ct><packing><property name=\"expand\">False</property><property name=\""
  "fill\">False</property><property name=\"position\">0</property><propert"
  "y name=\"secondary\">True</property></packing></child></object><packing"
  "><property name=\"expand\">False</property><property name=\"fill\">True"
  "</property><property name=\"pack_type\">end</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkNote"
  "book\" id=\"plug-child\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">True</property><property name=\"border_width\""
  ">6</property><child><object class=\"GtkScrolledWindow\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">True</property>"
  "<child><object class=\"GtkViewport\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><child><object cla"
  "ss=\"GtkBox\" id=\"vbox3\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"border_widt"
  "h\">12</property><property name=\"orientation\">vertical</property><pro"
  "perty name=\"spacing\">18</property><child><object class=\"GtkFrame\" i"
  "d=\"frame1\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"label_xalign\">0</property"
  "><property name=\"shadow_type\">none</property><child><object class=\"G"
  "tkAlignment\" id=\"alignment5\"><property name=\"visible\">True</proper"
  "ty><property name=\"can_focus\">False</property><property name=\"top_pa"
  "dding\">6</property><property name=\"left_padding\">12</property><child"
  "><object class=\"GtkCheckButton\" id=\"restore_numlock\"><property name"
  "=\"label\" translatable=\"yes\">Restore num l_ock state on startup</pro"
  "perty><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">True</property><property name=\"receives_default\">False</propert"
  "y><property name=\"halign\">start</property><property name=\"use_underl"
  "ine\">True</property><property name=\"draw_indicator\">True</property><"
  "/object></child></object></child><child type=\"label\"><object class=\""
  "GtkLabel\" id=\"label9\"><property name=\"visible\">True</property><pro"
  "perty name=\"can_focus\">False</property><property name=\"label\" trans"
  "latable=\"yes\">General</property><property name=\"use_markup\">True</p"
  "roperty><attributes><attribute name=\"weight\" value=\"bold\"/></attrib"
  "utes></object></child></object><packing><property name=\"expand\">False"
  "</property><property name=\"fill\">True</property><property name=\"posi"
  "tion\">0</property></packing></child><child><object class=\"GtkFrame\" "
  "id=\"frame2\"><property name=\"visible\">True</property><property name="
  "\"can_focus\">False</property><property name=\"label_xalign\">0</proper"
  "ty><property name=\"shadow_type\">none</property><child><object class=\""
  "GtkAlignment\" id=\"alignment2\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"top_p"
  "adding\">6</property><property name=\"left_padding\">12</property><chil"
  "d><object class=\"GtkBox\" id=\"vbox1\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"orientation\">vertical</property><property name=\"spacing\">6</proper"
  "ty><child><object class=\"GtkCheckButton\" id=\"xkb_key_repeat_check\">"
  "<property name=\"label\" translatable=\"yes\">_Enable key repeat</prope"
  "rty><property name=\"visible\">True</property><property name=\"can_focu"
  "s\">True</property><property name=\"receives_default\">False</property>"
  "<property name=\"tooltip_text\" translatable=\"yes\">When selected, pre"
  "ssing and holding down a key emits the same character over and over aga"
  "in</property><property name=\"halign\">start</property><property name=\""
  "use_underline\">True</property><property name=\"active\">True</property"
  "><property name=\"draw_indicator\">True</property></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">False</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkAlignment\" id=\"xkb_key_repeat_box\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"left_padding\">12</property><child><object class=\""
  "GtkBox\" id=\"vbox6\"><property name=\"visible\">True</property><proper"
  "ty name=\"can_focus\">False</property><property name=\"orientation\">ve"
  "rtical</property><property name=\"spacing\">6</property><child><object "
  "class=\"GtkLabel\" id=\"label7\"><property name=\"visible\">True</prope"
  "rty><property name=\"can_focus\">False</property><property name=\"halig"
  "n\">start</property><property name=\"label\" translatable=\"yes\">_Repe"
  "at delay:</property><property name=\"use_underline\">True</property><pr"
  "operty name=\"mnemonic_widget\">xkb_key_repeat_delay_scale</property></"
  "object><packing><property name=\"expand\">False</property><property nam"
  "e=\"fill\">False</property><property name=\"position\">0</property></pa"
  "cking></child><child><object class=\"GtkScale\" id=\"xkb_key_repeat_del"
  "ay_scale\"><property name=\"visible\">True</property><property name=\"c"
  "an_focus\">True</property><property name=\"tooltip_text\" translatable="
  "\"yes\">The time, in milliseconds, before a pressed key begins repeatin"
  "g</property><property name=\"adjustment\">xkb_key_repeat_delay</propert"
  "y><property name=\"digits\">0</property><property name=\"value_pos\">ri"
  "ght</property></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">1<"
  "/property></packing></child><child><object class=\"GtkLabel\" id=\"labe"
  "l10\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"halign\">start</property><proper"
  "ty name=\"label\" translatable=\"yes\">Repe_at speed:</property><proper"
  "ty name=\"use_underline\">True</property><property name=\"mnemonic_widg"
  "et\">xkb_key_repeat_rate_scale</property></object><packing><property na"
  "me=\"expand\">False</property><property name=\"fill\">False</property><"
  "property name=\"position\">2</property></packing></child><child><object"
  " class=\"GtkScale\" id=\"xkb_key_repeat_rate_scale\"><property name=\"v"
  "isible\">True</property><property name=\"can_focus\">True</property><pr"
  "operty name=\"tooltip_text\" translatable=\"yes\">The rate at which key"
  "strokes are generated while a key is pressed</property><property name=\""
  "adjustment\">xkb_key_repeat_rate</property><property name=\"digits\">0<"
  "/property><property name=\"value_pos\">right</property></object><packin"
  "g><property name=\"expand\">True</property><property name=\"fill\">True"
  "</property><property name=\"position\">3</property></packing></child></"
  "object></child></object><packing><property name=\"expand\">True</proper"
  "ty><property name=\"fill\">True</property><property name=\"position\">1"
  "</property></packing></child></object></child></object></child><child t"
  "ype=\"label\"><object class=\"GtkLabel\" id=\"label5\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"label\" translatable=\"yes\">Typing Settings</property>"
  "<attributes><attribute name=\"weight\" value=\"bold\"/></attributes></o"
  "bject></child></object><packing><property name=\"expand\">False</proper"
  "ty><property name=\"fill\">False</property><property name=\"position\">"
  "1</property></packing></child><child><object class=\"GtkFrame\" id=\"fr"
  "ame3\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">False</property><property name=\"label_xalign\">0</property><pro"
  "perty name=\"shadow_type\">none</property><child><object class=\"GtkAli"
  "gnment\" id=\"alignment3\"><property name=\"visible\">True</property><p"
  "roperty name=\"can_focus\">False</property><property name=\"top_padding"
  "\">6</property><property name=\"left_padding\">12</property><child><obj"
  "ect class=\"GtkBox\" id=\"vbox4\"><property name=\"visible\">True</prop"
  "erty><property name=\"can_focus\">False</property><property name=\"orie"
  "ntation\">vertical</property><property name=\"spacing\">6</property><ch"
  "ild><object class=\"GtkCheckButton\" id=\"net_cursor_blink_check\"><pro"
  "perty name=\"label\" translatable=\"yes\">Show _blinking</property><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"receives_default\">False</property><propert"
  "y name=\"tooltip_text\" translatable=\"yes\">Specify whether or not the"
  " text cursor blinks</property><property name=\"halign\">start</property"
  "><property name=\"use_underline\">True</property><property name=\"draw_"
  "indicator\">True</property></object><packing><property name=\"expand\">"
  "False</property><property name=\"fill\">False</property><property name="
  "\"position\">0</property></packing></child><child><object class=\"GtkAl"
  "ignment\" id=\"net_cursor_blink_box\"><property name=\"visible\">True</"
  "property><property name=\"sensitive\">False</property><property name=\""
  "can_focus\">False</property><property name=\"left_padding\">12</propert"
  "y><child><object class=\"GtkBox\" id=\"vbox7\"><property name=\"visible"
  "\">True</property><property name=\"can_focus\">False</property><propert"
  "y name=\"orientation\">vertical</property><property name=\"spacing\">6<"
  "/property><child><object class=\"GtkLabel\" id=\"label13\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"halign\">start</property><property name=\"label\" "
  "translatable=\"yes\">Blink _delay:</property><property name=\"use_under"
  "line\">True</property><property name=\"mnemonic_widget\">net_cursor_bli"
  "nk_time_scale</property></object><packing><property name=\"expand\">Fal"
  "se</property><property name=\"fill\">False</property><property name=\"p"
  "osition\">0</property></packing></child><child><object class=\"GtkScale"
  "\" id=\"net_cursor_blink_time_scale\"><property name=\"visible\">True</"
  "property><property name=\"can_focus\">True</property><property name=\"t"
  "ooltip_text\" translatable=\"yes\">The delay, in milliseconds, between "
  "successive blinks of the cursor</property><property name=\"adjustment\""
  ">net_cursor_blink_time</property><property name=\"digits\">0</property>"
  "<property name=\"value_pos\">right</property></object><packing><propert"
  "y name=\"expand\">True</property><property name=\"fill\">True</property"
  "><property name=\"position\">1</property></packing></child></object></c"
  "hild></object><packing><property name=\"expand\">False</property><prope"
  "rty name=\"fill\">True</property><property name=\"position\">1</propert"
  "y></packing></child></object></child></object></child><child type=\"lab"
  "el\"><object class=\"GtkLabel\" id=\"label6\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"label\" translatable=\"yes\">Cursor</property><attributes><attri"
  "bute name=\"weight\" value=\"bold\"/></attributes></object></child></ob"
  "ject><packing><property name=\"expand\">True</property><property name=\""
  "fill\">True</property><property name=\"position\">2</property></packing"
  "></child><child><object class=\"GtkBox\" id=\"hbox1\"><property name=\""
  "visible\">True</property><property name=\"can_focus\">False</property><"
  "property name=\"spacing\">12</property><child><object class=\"GtkLabel\""
  " id=\"label12\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"label\" translatable=\""
  "yes\">_Test area:</property><property name=\"use_underline\">True</prop"
  "erty><property name=\"mnemonic_widget\">entry1</property></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">T"
  "rue</property><property name=\"position\">0</property></packing></child"
  "><child><object class=\"GtkEntry\" id=\"entry1\"><property name=\"visib"
  "le\">True</property><property name=\"can_focus\">True</property><proper"
  "ty name=\"invisible_char\">\342\200\242</property><property name=\"prim"
  "ary_icon_activatable\">False</property><property name=\"secondary_icon_"
  "activatable\">False</property></object><packing><property name=\"expand"
  "\">True</property><property name=\"fill\">True</property><property name"
  "=\"position\">1</property></packing></child></object><packing><property"
  " name=\"expand\">False</property><property name=\"fill\">True</property"
  "><property name=\"position\">3</property></packing></child></object></c"
  "hild></object></child></object></child><child type=\"tab\"><object clas"
  "s=\"GtkLabel\" id=\"label2\"><property name=\"visible\">True</property>"
  "<property name=\"can_focus\">False</property><property name=\"label\" t"
  "ranslatable=\"yes\">Beha_vior</property><property name=\"use_underline\""
  ">True</property></object><packing><property name=\"tab_fill\">False</pr"
  "operty></packing></child><child><object class=\"GtkBox\" id=\"vbox5\"><"
  "property name=\"visible\">True</property><property name=\"can_focus\">F"
  "alse</property><property name=\"border_width\">12</property><property n"
  "ame=\"orientation\">vertical</property><child><object class=\"GtkLabel\""
  " id=\"label14\"><property name=\"visible\">True</property><property nam"
  "e=\"can_focus\">False</property><property name=\"margin_bottom\">6</pro"
  "perty><property name=\"label\" translatable=\"yes\">Define shortcuts fo"
  "r la_unching applications:</property><property name=\"use_underline\">T"
  "rue</property><property name=\"mnemonic_widget\">kbd_shortcuts_view</pr"
  "operty><property name=\"xalign\">0</property></object><packing><propert"
  "y name=\"expand\">False</property><property name=\"fill\">False</proper"
  "ty><property name=\"position\">0</property></packing></child><child><ob"
  "ject class=\"GtkScrolledWindow\" id=\"scrolledwindow2\"><property name="
  "\"visible\">True</property><property name=\"can_focus\">True</property>"
  "<property name=\"shadow_type\">etched-in</property><child><object class"
  "=\"GtkTreeView\" id=\"kbd_shortcuts_view\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">True</property><property nam"
  "e=\"search_column\">0</property><child internal-child=\"selection\"><ob"
  "ject class=\"GtkTreeSelection\" id=\"treeview-selection2\"/></child></o"
  "bject></child></object><packing><property name=\"expand\">True</propert"
  "y><property name=\"fill\">True</property><property name=\"position\">1<"
  "/property></packing></child><child><object class=\"GtkBox\"><property n"
  "ame=\"visible\">True</property><property name=\"can_focus\">False</prop"
  "erty><child><object class=\"GtkBox\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">False</property><child><object cla"
  "ss=\"GtkButton\" id=\"add_shortcut_button\"><property name=\"label\">_A"
  "dd</property><property name=\"visible\">True</property><property name=\""
  "can_focus\">True</property><property name=\"receives_default\">True</pr"
  "operty><property name=\"image\">image6</property><property name=\"use_u"
  "nderline\">True</property></object><packing><property name=\"expand\">F"
  "alse</property><property name=\"fill\">False</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkButt"
  "on\" id=\"edit_shortcut_button\"><property name=\"label\">_Edit</proper"
  "ty><property name=\"visible\">True</property><property name=\"can_focus"
  "\">True</property><property name=\"receives_default\">True</property><p"
  "roperty name=\"image\">image8</property><property name=\"use_underline\""
  ">True</property></object><packing><property name=\"expand\">False</prop"
  "erty><property name=\"fill\">False</property><property name=\"position\""
  ">1</property></packing></child><child><object class=\"GtkButton\" id=\""
  "delete_shortcut_button\"><property name=\"label\">_Remove</property><pr"
  "operty name=\"visible\">True</property><property name=\"can_focus\">Tru"
  "e</property><property name=\"receives_default\">True</property><propert"
  "y name=\"image\">image7</property><property name=\"use_underline\">True"
  "</property></object><packing><property name=\"expand\">False</property>"
  "<property name=\"fill\">True</property><property name=\"position\">2</p"
  "roperty></packing></child></object><packing><property name=\"expand\">F"
  "alse</property><property name=\"fill\">False</property><property name=\""
  "position\">0</property></packing></child><child><object class=\"GtkBox\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property><child><object class=\"GtkButton\" id=\"reset_shortcut"
  "s_button\"><property name=\"label\" translatable=\"yes\">Reset to _Defa"
  "ults</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">True<"
  "/property><property name=\"image\">image1</property><property name=\"us"
  "e_underline\">True</property></object><packing><property name=\"expand\""
  ">False</property><property name=\"fill\">True</property><property name="
  "\"position\">0</property></packing></child></object><packing><property "
  "name=\"expand\">False</property><property name=\"fill\">True</property>"
  "<property name=\"pack_type\">end</property><property name=\"position\">"
  "1</property></packing></child><style><class name=\"inline-toolbar\"/></"
  "style></object><packing><property name=\"expand\">False</property><prop"
  "erty name=\"fill\">True</property><property name=\"position\">2</proper"
  "ty></packing></child></object><packing><property name=\"position\">1</p"
  "roperty></packing></child><child type=\"tab\"><object class=\"GtkLabel\""
  " id=\"label3\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"label\" translatable=\""
  "yes\">A_pplication Shortcuts</property><property name=\"use_underline\""
  ">True</property></object><packing><property name=\"position\">1</proper"
  "ty><property name=\"tab_fill\">False</property></packing></child><child"
  "><object class=\"GtkScrolledWindow\"><property name=\"visible\">True</p"
  "roperty><property name=\"can_focus\">True</property><child><object clas"
  "s=\"GtkViewport\"><property name=\"visible\">True</property><property n"
  "ame=\"can_focus\">False</property><child><object class=\"GtkBox\" id=\""
  "xkb_tab_layout_vbox\"><property name=\"can_focus\">False</property><pro"
  "perty name=\"border_width\">12</property><property name=\"orientation\""
  ">vertical</property><property name=\"spacing\">18</property><child><obj"
  "ect class=\"GtkBox\"><property name=\"visible\">True</property><propert"
  "y name=\"can_focus\">False</property><child><object class=\"GtkLabel\">"
  "<property name=\"visible\">True</property><property name=\"can_focus\">"
  "False</property><property name=\"label\" translatable=\"yes\">&lt;b&gt;"
  "Use system defaults&lt;/b&gt;</property><property name=\"use_markup\">T"
  "rue</property><property name=\"xalign\">0</property></object><packing><"
  "property name=\"expand\">True</property><property name=\"fill\">True</p"
  "roperty><property name=\"position\">0</property></packing></child><chil"
  "d><object class=\"GtkSwitch\" id=\"xkb_use_system_default_switch\"><pro"
  "perty name=\"visible\">True</property><property name=\"can_focus\">True"
  "</property><property name=\"halign\">end</property><property name=\"val"
  "ign\">center</property></object><packing><property name=\"expand\">Fals"
  "e</property><property name=\"fill\">True</property><property name=\"pos"
  "ition\">1</property></packing></child></object><packing><property name="
  "\"expand\">False</property><property name=\"fill\">True</property><prop"
  "erty name=\"position\">0</property></packing></child><child><object cla"
  "ss=\"GtkFrame\" id=\"xkb_model_frame\"><property name=\"visible\">True<"
  "/property><property name=\"can_focus\">False</property><property name=\""
  "label_xalign\">0</property><property name=\"shadow_type\">none</propert"
  "y><child><object class=\"GtkAlignment\" id=\"alignment1\"><property nam"
  "e=\"visible\">True</property><property name=\"can_focus\">False</proper"
  "ty><property name=\"top_padding\">6</property><property name=\"left_pad"
  "ding\">12</property><child><object class=\"GtkComboBox\" id=\"xkb_model"
  "_combo\"><property name=\"visible\">True</property><property name=\"can"
  "_focus\">False</property></object></child></object></child><child type="
  "\"label\"><object class=\"GtkLabel\" id=\"label11\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"label\" translatable=\"yes\">_Keyboard model</property><p"
  "roperty name=\"use_underline\">True</property><attributes><attribute na"
  "me=\"weight\" value=\"bold\"/></attributes></object></child></object><p"
  "acking><property name=\"expand\">False</property><property name=\"fill\""
  ">True</property><property name=\"position\">1</property></packing></chi"
  "ld><child><object class=\"GtkBox\" id=\"hbox4\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">False</property><proper"
  "ty name=\"spacing\">6</property><property name=\"homogeneous\">True</pr"
  "operty><child><object class=\"GtkFrame\" id=\"xkb_grpkey_frame\"><prope"
  "rty name=\"visible\">True</property><property name=\"can_focus\">False<"
  "/property><property name=\"label_xalign\">0</property><property name=\""
  "shadow_type\">none</property><child><object class=\"GtkAlignment\" id=\""
  "alignment6\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"top_padding\">6</property>"
  "<property name=\"left_padding\">12</property><child><object class=\"Gtk"
  "ComboBox\" id=\"xkb_grpkey_combo\"><property name=\"visible\">True</pro"
  "perty><property name=\"can_focus\">False</property></object></child></o"
  "bject></child><child type=\"label\"><object class=\"GtkLabel\" id=\"lab"
  "el1\"><property name=\"visible\">True</property><property name=\"can_fo"
  "cus\">False</property><property name=\"label\" translatable=\"yes\">Cha"
  "nge la_yout option</property><property name=\"use_underline\">True</pro"
  "perty><attributes><attribute name=\"weight\" value=\"bold\"/></attribut"
  "es></object></child></object><packing><property name=\"expand\">False</"
  "property><property name=\"fill\">True</property><property name=\"positi"
  "on\">0</property></packing></child><child><object class=\"GtkFrame\" id"
  "=\"xkb_composekey_frame\"><property name=\"visible\">True</property><pr"
  "operty name=\"can_focus\">False</property><property name=\"label_xalign"
  "\">0</property><property name=\"shadow_type\">none</property><child><ob"
  "ject class=\"GtkAlignment\" id=\"alignment7\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"top_padding\">6</property><property name=\"left_padding\">12</pr"
  "operty><child><object class=\"GtkComboBox\" id=\"xkb_composekey_combo\""
  "><property name=\"visible\">True</property><property name=\"can_focus\""
  ">False</property></object></child></object></child><child type=\"label\""
  "><object class=\"GtkLabel\" id=\"label15\"><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">False</property><property na"
  "me=\"label\" translatable=\"yes\">Co_mpose key</property><property name"
  "=\"use_underline\">True</property><attributes><attribute name=\"weight\""
  " value=\"bold\"/></attributes></object></child></object><packing><prope"
  "rty name=\"expand\">False</property><property name=\"fill\">True</prope"
  "rty><property name=\"position\">1</property></packing></child></object>"
  "<packing><property name=\"expand\">False</property><property name=\"fil"
  "l\">True</property><property name=\"position\">2</property></packing></"
  "child><child><object class=\"GtkFrame\" id=\"xkb_layout_frame\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">False</"
  "property><property name=\"label_xalign\">0</property><property name=\"s"
  "hadow_type\">none</property><child><object class=\"GtkAlignment\" id=\""
  "alignment4\"><property name=\"visible\">True</property><property name=\""
  "can_focus\">False</property><property name=\"top_padding\">6</property>"
  "<child><object class=\"GtkBox\" id=\"vbox8\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">False</property><property "
  "name=\"spacing\">6</property><child><object class=\"GtkBox\" id=\"hbox3"
  "\"><property name=\"visible\">True</property><property name=\"can_focus"
  "\">False</property><property name=\"orientation\">vertical</property><c"
  "hild><object class=\"GtkScrolledWindow\" id=\"scrolledwindow1\"><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"shadow_type\">etched-in</property><child><obje"
  "ct class=\"GtkTreeView\" id=\"xkb_layout_view\"><property name=\"visibl"
  "e\">True</property><property name=\"can_focus\">True</property><propert"
  "y name=\"search_column\">0</property><child internal-child=\"selection\""
  "><object class=\"GtkTreeSelection\" id=\"treeview-selection3\"/></child"
  "></object></child></object><packing><property name=\"expand\">True</pro"
  "perty><property name=\"fill\">True</property><property name=\"position\""
  ">0</property></packing></child><child><object class=\"GtkButtonBox\" id"
  "=\"hbuttonbox2\"><property name=\"visible\">True</property><property na"
  "me=\"can_focus\">False</property><property name=\"layout_style\">start<"
  "/property><child><object class=\"GtkButton\" id=\"xkb_layout_add_button"
  "\"><property name=\"label\">_Add</property><property name=\"visible\">T"
  "rue</property><property name=\"can_focus\">True</property><property nam"
  "e=\"receives_default\">True</property><property name=\"image\">image9</"
  "property><property name=\"use_underline\">True</property></object><pack"
  "ing><property name=\"expand\">False</property><property name=\"fill\">F"
  "alse</property><property name=\"position\">0</property><property name=\""
  "non_homogeneous\">True</property></packing></child><child><object class"
  "=\"GtkButton\" id=\"xkb_layout_edit_button\"><property name=\"label\">_"
  "Edit</property><property name=\"visible\">True</property><property name"
  "=\"can_focus\">True</property><property name=\"receives_default\">True<"
  "/property><property name=\"image\">image10</property><property name=\"u"
  "se_underline\">True</property></object><packing><property name=\"expand"
  "\">False</property><property name=\"fill\">False</property><property na"
  "me=\"position\">1</property><property name=\"non_homogeneous\">True</pr"
  "operty></packing></child><child><object class=\"GtkButton\" id=\"xkb_la"
  "yout_delete_button\"><property name=\"label\">_Remove</property><proper"
  "ty name=\"visible\">True</property><property name=\"can_focus\">True</p"
  "roperty><property name=\"receives_default\">True</property><property na"
  "me=\"image\">image11</property><property name=\"use_underline\">True</p"
  "roperty></object><packing><property name=\"expand\">False</property><pr"
  "operty name=\"fill\">False</property><property name=\"position\">2</pro"
  "perty><property name=\"non_homogeneous\">True</property></packing></chi"
  "ld><style><class name=\"inline-toolbar\"/></style></object><packing><pr"
  "operty name=\"expand\">False</property><property name=\"fill\">True</pr"
  "operty><property name=\"position\">1</property></packing></child></obje"
  "ct><packing><property name=\"expand\">True</property><property name=\"f"
  "ill\">True</property><property name=\"position\">0</property></packing>"
  "</child><child><object class=\"GtkBox\" id=\"vbuttonbox1\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"orientation\">vertical</property><child><object cl"
  "ass=\"GtkButton\" id=\"xkb_layout_up_button\"><property name=\"visible\""
  ">True</property><property name=\"can_focus\">True</property><property n"
  "ame=\"receives_default\">True</property><property name=\"tooltip_text\""
  " translatable=\"yes\">Move currently selected item up by one row</prope"
  "rty><child><object class=\"GtkImage\" id=\"image4\"><property name=\"vi"
  "sible\">True</property><property name=\"can_focus\">False</property><pr"
  "operty name=\"icon_name\">go-up-symbolic</property></object></child></o"
  "bject><packing><property name=\"expand\">False</property><property name"
  "=\"fill\">False</property><property name=\"position\">0</property></pac"
  "king></child><child><object class=\"GtkButton\" id=\"xkb_layout_down_bu"
  "tton\"><property name=\"visible\">True</property><property name=\"can_f"
  "ocus\">True</property><property name=\"receives_default\">True</propert"
  "y><property name=\"tooltip_text\" translatable=\"yes\">Move currently s"
  "elected item down by one row</property><child><object class=\"GtkImage\""
  " id=\"image3\"><property name=\"visible\">True</property><property name"
  "=\"can_focus\">False</property><property name=\"icon_name\">go-down-sym"
  "bolic</property></object></child></object><packing><property name=\"exp"
  "and\">False</property><property name=\"fill\">False</property><property"
  " name=\"position\">1</property></packing></child><style><class name=\"l"
  "inked\"/></style></object><packing><property name=\"expand\">False</pro"
  "perty><property name=\"fill\">False</property><property name=\"position"
  "\">2</property></packing></child></object></child></object></child><chi"
  "ld type=\"label\"><object class=\"GtkLabel\" id=\"label8\"><property na"
  "me=\"visible\">True</property><property name=\"can_focus\">False</prope"
  "rty><property name=\"label\" translatable=\"yes\">Key_board layout</pro"
  "perty><property name=\"use_underline\">True</property><attributes><attr"
  "ibute name=\"weight\" value=\"bold\"/></attributes></object></child></o"
  "bject><packing><property name=\"expand\">True</property><property name="
  "\"fill\">True</property><property name=\"position\">3</property></packi"
  "ng></child></object></child></object></child></object><packing><propert"
  "y name=\"position\">2</property></packing></child><child type=\"tab\"><"
  "object class=\"GtkLabel\" id=\"label4\"><property name=\"visible\">True"
  "</property><property name=\"can_focus\">False</property><property name="
  "\"label\" translatable=\"yes\">_Layout</property><property name=\"use_u"
  "nderline\">True</property></object><packing><property name=\"position\""
  ">2</property><property name=\"tab_fill\">False</property></packing></ch"
  "ild></object><packing><property name=\"expand\">True</property><propert"
  "y name=\"fill\">True</property><property name=\"position\">1</property>"
  "</packing></child></object></child><action-widgets><action-widget respo"
  "nse=\"0\">button2</action-widget><action-widget response=\"-11\">button"
  "1</action-widget></action-widgets></object></interface>"
};

static const unsigned keyboard_dialog_ui_length = 35472u;

